#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkPoints
from vtkmodules.vtkCommonDataModel import (
    vtkHexagonalPrism,
    vtkHexahedron,
    vtkLine,
    vtkPentagonalPrism,
    vtkPixel,
    vtkPolyLine,
    vtkPolyVertex,
    vtkPolygon,
    vtkPyramid,
    vtkQuad,
    vtkTetra,
    vtkTriangle,
    vtkTriangleStrip,
    vtkUnstructuredGrid,
    vtkVertex,
    vtkVoxel,
    vtkWedge,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCellPicker,
    vtkDataSetMapper,
    vtkPointPicker,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkWorldPointPicker,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# create a scene with one of each cell type
# Voxel
voxelPoints = vtkPoints()
voxelPoints.SetNumberOfPoints(8)
voxelPoints.InsertPoint(0,0,0,0)
voxelPoints.InsertPoint(1,1,0,0)
voxelPoints.InsertPoint(2,0,1,0)
voxelPoints.InsertPoint(3,1,1,0)
voxelPoints.InsertPoint(4,0,0,1)
voxelPoints.InsertPoint(5,1,0,1)
voxelPoints.InsertPoint(6,0,1,1)
voxelPoints.InsertPoint(7,1,1,1)
aVoxel = vtkVoxel()
aVoxel.GetPointIds().SetId(0,0)
aVoxel.GetPointIds().SetId(1,1)
aVoxel.GetPointIds().SetId(2,2)
aVoxel.GetPointIds().SetId(3,3)
aVoxel.GetPointIds().SetId(4,4)
aVoxel.GetPointIds().SetId(5,5)
aVoxel.GetPointIds().SetId(6,6)
aVoxel.GetPointIds().SetId(7,7)
aVoxelGrid = vtkUnstructuredGrid()
aVoxelGrid.Allocate(1,1)
aVoxelGrid.InsertNextCell(aVoxel.GetCellType(),aVoxel.GetPointIds())
aVoxelGrid.SetPoints(voxelPoints)
aVoxelMapper = vtkDataSetMapper()
aVoxelMapper.SetInputData(aVoxelGrid)
aVoxelActor = vtkActor()
aVoxelActor.SetMapper(aVoxelMapper)
aVoxelActor.GetProperty().BackfaceCullingOn()
# Hexahedron
hexahedronPoints = vtkPoints()
hexahedronPoints.SetNumberOfPoints(8)
hexahedronPoints.InsertPoint(0,0,0,0)
hexahedronPoints.InsertPoint(1,1,0,0)
hexahedronPoints.InsertPoint(2,1,1,0)
hexahedronPoints.InsertPoint(3,0,1,0)
hexahedronPoints.InsertPoint(4,0,0,1)
hexahedronPoints.InsertPoint(5,1,0,1)
hexahedronPoints.InsertPoint(6,1,1,1)
hexahedronPoints.InsertPoint(7,0,1,1)
aHexahedron = vtkHexahedron()
aHexahedron.GetPointIds().SetId(0,0)
aHexahedron.GetPointIds().SetId(1,1)
aHexahedron.GetPointIds().SetId(2,2)
aHexahedron.GetPointIds().SetId(3,3)
aHexahedron.GetPointIds().SetId(4,4)
aHexahedron.GetPointIds().SetId(5,5)
aHexahedron.GetPointIds().SetId(6,6)
aHexahedron.GetPointIds().SetId(7,7)
aHexahedronGrid = vtkUnstructuredGrid()
aHexahedronGrid.Allocate(1,1)
aHexahedronGrid.InsertNextCell(aHexahedron.GetCellType(),aHexahedron.GetPointIds())
aHexahedronGrid.SetPoints(hexahedronPoints)
aHexahedronMapper = vtkDataSetMapper()
aHexahedronMapper.SetInputData(aHexahedronGrid)
aHexahedronActor = vtkActor()
aHexahedronActor.SetMapper(aHexahedronMapper)
aHexahedronActor.AddPosition(2,0,0)
aHexahedronActor.GetProperty().BackfaceCullingOn()
# Tetra
tetraPoints = vtkPoints()
tetraPoints.SetNumberOfPoints(4)
tetraPoints.InsertPoint(0,0,0,0)
tetraPoints.InsertPoint(1,1,0,0)
tetraPoints.InsertPoint(2,.5,1,0)
tetraPoints.InsertPoint(3,.5,.5,1)
aTetra = vtkTetra()
aTetra.GetPointIds().SetId(0,0)
aTetra.GetPointIds().SetId(1,1)
aTetra.GetPointIds().SetId(2,2)
aTetra.GetPointIds().SetId(3,3)
aTetraGrid = vtkUnstructuredGrid()
aTetraGrid.Allocate(1,1)
aTetraGrid.InsertNextCell(aTetra.GetCellType(),aTetra.GetPointIds())
aTetraGrid.SetPoints(tetraPoints)
aTetraMapper = vtkDataSetMapper()
aTetraMapper.SetInputData(aTetraGrid)
aTetraActor = vtkActor()
aTetraActor.SetMapper(aTetraMapper)
aTetraActor.AddPosition(4,0,0)
aTetraActor.GetProperty().BackfaceCullingOn()
# Wedge
wedgePoints = vtkPoints()
wedgePoints.SetNumberOfPoints(6)
wedgePoints.InsertPoint(0,0,1,0)
wedgePoints.InsertPoint(1,0,0,0)
wedgePoints.InsertPoint(2,0,.5,.5)
wedgePoints.InsertPoint(3,1,1,0)
wedgePoints.InsertPoint(4,1,0,0)
wedgePoints.InsertPoint(5,1,.5,.5)
aWedge = vtkWedge()
aWedge.GetPointIds().SetId(0,0)
aWedge.GetPointIds().SetId(1,1)
aWedge.GetPointIds().SetId(2,2)
aWedge.GetPointIds().SetId(3,3)
aWedge.GetPointIds().SetId(4,4)
aWedge.GetPointIds().SetId(5,5)
aWedgeGrid = vtkUnstructuredGrid()
aWedgeGrid.Allocate(1,1)
aWedgeGrid.InsertNextCell(aWedge.GetCellType(),aWedge.GetPointIds())
aWedgeGrid.SetPoints(wedgePoints)
aWedgeMapper = vtkDataSetMapper()
aWedgeMapper.SetInputData(aWedgeGrid)
aWedgeActor = vtkActor()
aWedgeActor.SetMapper(aWedgeMapper)
aWedgeActor.AddPosition(6,0,0)
aWedgeActor.GetProperty().BackfaceCullingOn()
# Pyramid
pyramidPoints = vtkPoints()
pyramidPoints.SetNumberOfPoints(5)
pyramidPoints.InsertPoint(0,0,0,0)
pyramidPoints.InsertPoint(1,1,0,0)
pyramidPoints.InsertPoint(2,1,1,0)
pyramidPoints.InsertPoint(3,0,1,0)
pyramidPoints.InsertPoint(4,.5,.5,1)
aPyramid = vtkPyramid()
aPyramid.GetPointIds().SetId(0,0)
aPyramid.GetPointIds().SetId(1,1)
aPyramid.GetPointIds().SetId(2,2)
aPyramid.GetPointIds().SetId(3,3)
aPyramid.GetPointIds().SetId(4,4)
aPyramidGrid = vtkUnstructuredGrid()
aPyramidGrid.Allocate(1,1)
aPyramidGrid.InsertNextCell(aPyramid.GetCellType(),aPyramid.GetPointIds())
aPyramidGrid.SetPoints(pyramidPoints)
aPyramidMapper = vtkDataSetMapper()
aPyramidMapper.SetInputData(aPyramidGrid)
aPyramidActor = vtkActor()
aPyramidActor.SetMapper(aPyramidMapper)
aPyramidActor.AddPosition(8,0,0)
aPyramidActor.GetProperty().BackfaceCullingOn()
# Pixel
pixelPoints = vtkPoints()
pixelPoints.SetNumberOfPoints(4)
pixelPoints.InsertPoint(0,0,0,0)
pixelPoints.InsertPoint(1,1,0,0)
pixelPoints.InsertPoint(2,0,1,0)
pixelPoints.InsertPoint(3,1,1,0)
aPixel = vtkPixel()
aPixel.GetPointIds().SetId(0,0)
aPixel.GetPointIds().SetId(1,1)
aPixel.GetPointIds().SetId(2,2)
aPixel.GetPointIds().SetId(3,3)
aPixelGrid = vtkUnstructuredGrid()
aPixelGrid.Allocate(1,1)
aPixelGrid.InsertNextCell(aPixel.GetCellType(),aPixel.GetPointIds())
aPixelGrid.SetPoints(pixelPoints)
aPixelMapper = vtkDataSetMapper()
aPixelMapper.SetInputData(aPixelGrid)
aPixelActor = vtkActor()
aPixelActor.SetMapper(aPixelMapper)
aPixelActor.AddPosition(0,0,2)
aPixelActor.GetProperty().BackfaceCullingOn()
# Quad
quadPoints = vtkPoints()
quadPoints.SetNumberOfPoints(4)
quadPoints.InsertPoint(0,0,0,0)
quadPoints.InsertPoint(1,1,0,0)
quadPoints.InsertPoint(2,1,1,0)
quadPoints.InsertPoint(3,0,1,0)
aQuad = vtkQuad()
aQuad.GetPointIds().SetId(0,0)
aQuad.GetPointIds().SetId(1,1)
aQuad.GetPointIds().SetId(2,2)
aQuad.GetPointIds().SetId(3,3)
aQuadGrid = vtkUnstructuredGrid()
aQuadGrid.Allocate(1,1)
aQuadGrid.InsertNextCell(aQuad.GetCellType(),aQuad.GetPointIds())
aQuadGrid.SetPoints(quadPoints)
aQuadMapper = vtkDataSetMapper()
aQuadMapper.SetInputData(aQuadGrid)
aQuadActor = vtkActor()
aQuadActor.SetMapper(aQuadMapper)
aQuadActor.AddPosition(2,0,2)
aQuadActor.GetProperty().BackfaceCullingOn()
# Triangle
trianglePoints = vtkPoints()
trianglePoints.SetNumberOfPoints(3)
trianglePoints.InsertPoint(0,0,0,0)
trianglePoints.InsertPoint(1,1,0,0)
trianglePoints.InsertPoint(2,.5,.5,0)
aTriangle = vtkTriangle()
aTriangle.GetPointIds().SetId(0,0)
aTriangle.GetPointIds().SetId(1,1)
aTriangle.GetPointIds().SetId(2,2)
aTriangleGrid = vtkUnstructuredGrid()
aTriangleGrid.Allocate(1,1)
aTriangleGrid.InsertNextCell(aTriangle.GetCellType(),aTriangle.GetPointIds())
aTriangleGrid.SetPoints(trianglePoints)
aTriangleMapper = vtkDataSetMapper()
aTriangleMapper.SetInputData(aTriangleGrid)
aTriangleActor = vtkActor()
aTriangleActor.SetMapper(aTriangleMapper)
aTriangleActor.AddPosition(4,0,2)
aTriangleActor.GetProperty().BackfaceCullingOn()
# Polygon
polygonPoints = vtkPoints()
polygonPoints.SetNumberOfPoints(4)
polygonPoints.InsertPoint(0,0,0,0)
polygonPoints.InsertPoint(1,1,0,0)
polygonPoints.InsertPoint(2,1,1,0)
polygonPoints.InsertPoint(3,0,1,0)
aPolygon = vtkPolygon()
aPolygon.GetPointIds().SetNumberOfIds(4)
aPolygon.GetPointIds().SetId(0,0)
aPolygon.GetPointIds().SetId(1,1)
aPolygon.GetPointIds().SetId(2,2)
aPolygon.GetPointIds().SetId(3,3)
aPolygonGrid = vtkUnstructuredGrid()
aPolygonGrid.Allocate(1,1)
aPolygonGrid.InsertNextCell(aPolygon.GetCellType(),aPolygon.GetPointIds())
aPolygonGrid.SetPoints(polygonPoints)
aPolygonMapper = vtkDataSetMapper()
aPolygonMapper.SetInputData(aPolygonGrid)
aPolygonActor = vtkActor()
aPolygonActor.SetMapper(aPolygonMapper)
aPolygonActor.AddPosition(6,0,2)
aPolygonActor.GetProperty().BackfaceCullingOn()
# Triangle Strip
triangleStripPoints = vtkPoints()
triangleStripPoints.SetNumberOfPoints(5)
triangleStripPoints.InsertPoint(0,0,1,0)
triangleStripPoints.InsertPoint(1,0,0,0)
triangleStripPoints.InsertPoint(2,1,1,0)
triangleStripPoints.InsertPoint(3,1,0,0)
triangleStripPoints.InsertPoint(4,2,1,0)
aTriangleStrip = vtkTriangleStrip()
aTriangleStrip.GetPointIds().SetNumberOfIds(5)
aTriangleStrip.GetPointIds().SetId(0,0)
aTriangleStrip.GetPointIds().SetId(1,1)
aTriangleStrip.GetPointIds().SetId(2,2)
aTriangleStrip.GetPointIds().SetId(3,3)
aTriangleStrip.GetPointIds().SetId(4,4)
aTriangleStripGrid = vtkUnstructuredGrid()
aTriangleStripGrid.Allocate(1,1)
aTriangleStripGrid.InsertNextCell(aTriangleStrip.GetCellType(),aTriangleStrip.GetPointIds())
aTriangleStripGrid.SetPoints(triangleStripPoints)
aTriangleStripMapper = vtkDataSetMapper()
aTriangleStripMapper.SetInputData(aTriangleStripGrid)
aTriangleStripActor = vtkActor()
aTriangleStripActor.SetMapper(aTriangleStripMapper)
aTriangleStripActor.AddPosition(8,0,2)
aTriangleStripActor.GetProperty().BackfaceCullingOn()
# Line
linePoints = vtkPoints()
linePoints.SetNumberOfPoints(2)
linePoints.InsertPoint(0,0,0,0)
linePoints.InsertPoint(1,1,1,0)
aLine = vtkLine()
aLine.GetPointIds().SetId(0,0)
aLine.GetPointIds().SetId(1,1)
aLineGrid = vtkUnstructuredGrid()
aLineGrid.Allocate(1,1)
aLineGrid.InsertNextCell(aLine.GetCellType(),aLine.GetPointIds())
aLineGrid.SetPoints(linePoints)
aLineMapper = vtkDataSetMapper()
aLineMapper.SetInputData(aLineGrid)
aLineActor = vtkActor()
aLineActor.SetMapper(aLineMapper)
aLineActor.AddPosition(0,0,4)
aLineActor.GetProperty().BackfaceCullingOn()
# Poly line
polyLinePoints = vtkPoints()
polyLinePoints.SetNumberOfPoints(3)
polyLinePoints.InsertPoint(0,0,0,0)
polyLinePoints.InsertPoint(1,1,1,0)
polyLinePoints.InsertPoint(2,1,0,0)
aPolyLine = vtkPolyLine()
aPolyLine.GetPointIds().SetNumberOfIds(3)
aPolyLine.GetPointIds().SetId(0,0)
aPolyLine.GetPointIds().SetId(1,1)
aPolyLine.GetPointIds().SetId(2,2)
aPolyLineGrid = vtkUnstructuredGrid()
aPolyLineGrid.Allocate(1,1)
aPolyLineGrid.InsertNextCell(aPolyLine.GetCellType(),aPolyLine.GetPointIds())
aPolyLineGrid.SetPoints(polyLinePoints)
aPolyLineMapper = vtkDataSetMapper()
aPolyLineMapper.SetInputData(aPolyLineGrid)
aPolyLineActor = vtkActor()
aPolyLineActor.SetMapper(aPolyLineMapper)
aPolyLineActor.AddPosition(2,0,4)
aPolyLineActor.GetProperty().BackfaceCullingOn()
# Vertex
vertexPoints = vtkPoints()
vertexPoints.SetNumberOfPoints(1)
vertexPoints.InsertPoint(0,0,0,0)
aVertex = vtkVertex()
aVertex.GetPointIds().SetId(0,0)
aVertexGrid = vtkUnstructuredGrid()
aVertexGrid.Allocate(1,1)
aVertexGrid.InsertNextCell(aVertex.GetCellType(),aVertex.GetPointIds())
aVertexGrid.SetPoints(vertexPoints)
aVertexMapper = vtkDataSetMapper()
aVertexMapper.SetInputData(aVertexGrid)
aVertexActor = vtkActor()
aVertexActor.SetMapper(aVertexMapper)
aVertexActor.AddPosition(0,0,6)
aVertexActor.GetProperty().BackfaceCullingOn()
# Poly Vertex
polyVertexPoints = vtkPoints()
polyVertexPoints.SetNumberOfPoints(3)
polyVertexPoints.InsertPoint(0,0,0,0)
polyVertexPoints.InsertPoint(1,1,0,0)
polyVertexPoints.InsertPoint(2,1,1,0)
aPolyVertex = vtkPolyVertex()
aPolyVertex.GetPointIds().SetNumberOfIds(3)
aPolyVertex.GetPointIds().SetId(0,0)
aPolyVertex.GetPointIds().SetId(1,1)
aPolyVertex.GetPointIds().SetId(2,2)
aPolyVertexGrid = vtkUnstructuredGrid()
aPolyVertexGrid.Allocate(1,1)
aPolyVertexGrid.InsertNextCell(aPolyVertex.GetCellType(),aPolyVertex.GetPointIds())
aPolyVertexGrid.SetPoints(polyVertexPoints)
aPolyVertexMapper = vtkDataSetMapper()
aPolyVertexMapper.SetInputData(aPolyVertexGrid)
aPolyVertexActor = vtkActor()
aPolyVertexActor.SetMapper(aPolyVertexMapper)
aPolyVertexActor.AddPosition(2,0,6)
aPolyVertexActor.GetProperty().BackfaceCullingOn()
# Pentagonal prism
pentaPoints = vtkPoints()
pentaPoints.SetNumberOfPoints(10)
pentaPoints.InsertPoint(0,0.25,0.0,0.0)
pentaPoints.InsertPoint(1,0.75,0.0,0.0)
pentaPoints.InsertPoint(2,1.0,0.5,0.0)
pentaPoints.InsertPoint(3,0.5,1.0,0.0)
pentaPoints.InsertPoint(4,0.0,0.5,0.0)
pentaPoints.InsertPoint(5,0.25,0.0,1.0)
pentaPoints.InsertPoint(6,0.75,0.0,1.0)
pentaPoints.InsertPoint(7,1.0,0.5,1.0)
pentaPoints.InsertPoint(8,0.5,1.0,1.0)
pentaPoints.InsertPoint(9,0.0,0.5,1.0)
aPenta = vtkPentagonalPrism()
aPenta.GetPointIds().SetId(0,0)
aPenta.GetPointIds().SetId(1,1)
aPenta.GetPointIds().SetId(2,2)
aPenta.GetPointIds().SetId(3,3)
aPenta.GetPointIds().SetId(4,4)
aPenta.GetPointIds().SetId(5,5)
aPenta.GetPointIds().SetId(6,6)
aPenta.GetPointIds().SetId(7,7)
aPenta.GetPointIds().SetId(8,8)
aPenta.GetPointIds().SetId(9,9)
aPentaGrid = vtkUnstructuredGrid()
aPentaGrid.Allocate(1,1)
aPentaGrid.InsertNextCell(aPenta.GetCellType(),aPenta.GetPointIds())
aPentaGrid.SetPoints(pentaPoints)
aPentaMapper = vtkDataSetMapper()
aPentaMapper.SetInputData(aPentaGrid)
aPentaActor = vtkActor()
aPentaActor.SetMapper(aPentaMapper)
aPentaActor.AddPosition(10,0,0)
aPentaActor.GetProperty().BackfaceCullingOn()
# Hexagonal prism
hexaPoints = vtkPoints()
hexaPoints.SetNumberOfPoints(12)
hexaPoints.InsertPoint(0,0.0,0.0,0.0)
hexaPoints.InsertPoint(1,0.5,0.0,0.0)
hexaPoints.InsertPoint(2,1.0,0.5,0.0)
hexaPoints.InsertPoint(3,1.0,1.0,0.0)
hexaPoints.InsertPoint(4,0.5,1.0,0.0)
hexaPoints.InsertPoint(5,0.0,0.5,0.0)
hexaPoints.InsertPoint(6,0.0,0.0,1.0)
hexaPoints.InsertPoint(7,0.5,0.0,1.0)
hexaPoints.InsertPoint(8,1.0,0.5,1.0)
hexaPoints.InsertPoint(9,1.0,1.0,1.0)
hexaPoints.InsertPoint(10,0.5,1.0,1.0)
hexaPoints.InsertPoint(11,0.0,0.5,1.0)
aHexa = vtkHexagonalPrism()
aHexa.GetPointIds().SetId(0,0)
aHexa.GetPointIds().SetId(1,1)
aHexa.GetPointIds().SetId(2,2)
aHexa.GetPointIds().SetId(3,3)
aHexa.GetPointIds().SetId(4,4)
aHexa.GetPointIds().SetId(5,5)
aHexa.GetPointIds().SetId(6,6)
aHexa.GetPointIds().SetId(7,7)
aHexa.GetPointIds().SetId(8,8)
aHexa.GetPointIds().SetId(9,9)
aHexa.GetPointIds().SetId(10,10)
aHexa.GetPointIds().SetId(11,11)
aHexaGrid = vtkUnstructuredGrid()
aHexaGrid.Allocate(1,1)
aHexaGrid.InsertNextCell(aHexa.GetCellType(),aHexa.GetPointIds())
aHexaGrid.SetPoints(hexaPoints)
aHexaMapper = vtkDataSetMapper()
aHexaMapper.SetInputData(aHexaGrid)
aHexaActor = vtkActor()
aHexaActor.SetMapper(aHexaMapper)
aHexaActor.AddPosition(12,0,0)
aHexaActor.GetProperty().BackfaceCullingOn()
ren1.SetBackground(.1,.2,.4)
ren1.AddActor(aVoxelActor)
aVoxelActor.GetProperty().SetDiffuseColor(1,0,0)
ren1.AddActor(aHexahedronActor)
aHexahedronActor.GetProperty().SetDiffuseColor(1,1,0)
ren1.AddActor(aTetraActor)
aTetraActor.GetProperty().SetDiffuseColor(0,1,0)
ren1.AddActor(aWedgeActor)
aWedgeActor.GetProperty().SetDiffuseColor(0,1,1)
ren1.AddActor(aPyramidActor)
aPyramidActor.GetProperty().SetDiffuseColor(1,0,1)
ren1.AddActor(aPixelActor)
aPixelActor.GetProperty().SetDiffuseColor(0,1,1)
ren1.AddActor(aQuadActor)
aQuadActor.GetProperty().SetDiffuseColor(1,0,1)
ren1.AddActor(aTriangleActor)
aTriangleActor.GetProperty().SetDiffuseColor(.3,1,.5)
ren1.AddActor(aPolygonActor)
aPolygonActor.GetProperty().SetDiffuseColor(1,.4,.5)
ren1.AddActor(aTriangleStripActor)
aTriangleStripActor.GetProperty().SetDiffuseColor(.3,.7,1)
ren1.AddActor(aLineActor)
aLineActor.GetProperty().SetDiffuseColor(.2,1,1)
ren1.AddActor(aPolyLineActor)
aPolyLineActor.GetProperty().SetDiffuseColor(1,1,1)
ren1.AddActor(aVertexActor)
aVertexActor.GetProperty().SetDiffuseColor(1,1,1)
ren1.AddActor(aPolyVertexActor)
aPolyVertexActor.GetProperty().SetDiffuseColor(1,1,1)
ren1.AddActor(aPentaActor)
aPentaActor.GetProperty().SetDiffuseColor(.2,.4,.7)
ren1.AddActor(aHexaActor)
aHexaActor.GetProperty().SetDiffuseColor(.7,.5,1)
ren1.ResetCamera()
ren1.GetActiveCamera().Azimuth(30)
ren1.GetActiveCamera().Elevation(20)
ren1.GetActiveCamera().Dolly(1.25)
ren1.ResetCameraClippingRange()
renWin.Render()
cellPicker = vtkCellPicker()
pointPicker = vtkPointPicker()
worldPicker = vtkWorldPointPicker()
cellCount = 0
pointCount = 0
ren1.IsInViewport(0,0)
x = 0
while x <= 265:
    y = 100
    while y <= 200:
        cellPicker.Pick(x,y,0,ren1)
        pointPicker.Pick(x,y,0,ren1)
        worldPicker.Pick(x,y,0,ren1)
        if (cellPicker.GetCellId() != "-1"):
            cellCount = cellCount + 1
        if (pointPicker.GetPointId() != "-1"):
            pointCount = pointCount + 1
        y = y + 6

    x = x + 6

# render the image
#
iren.Initialize()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import (
    vtkBoundingBox
)

from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Test various bounding box intersection methods with a sphere
#

# Define a bounding box
min = [-1.1,-1.1,-1.1]
max = [1.1,1.1,1.1]
bbox = vtkBoundingBox(min,max)

radius = 0.5

# Tests: box intersects sphere
center = [-2,0,0]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [2,0,0]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [0,-2,0]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [0,2,0]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [0,0,-2]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [0,0,-2]
assert (not bbox.IntersectsSphere(min,max,center,radius*radius))
assert (not bbox.IntersectsSphere(center,radius))

center = [0,0,0]
assert (bbox.IntersectsSphere(min,max,center,radius*radius))
assert (bbox.IntersectsSphere(center,radius))

center = [-1.25,0,0]
assert (bbox.IntersectsSphere(min,max,center,radius*radius))
assert (bbox.IntersectsSphere(center,radius))

# Tests: box inside sphere
radius = 3
center = [0,0,0]
assert (bbox.InsideSphere(min,max,center,radius*radius))

center = [-10,0,0]
assert (not bbox.InsideSphere(min,max,center,radius*radius))

center = [-2,0,0]
assert (not bbox.InsideSphere(min,max,center,radius*radius))



#!/usr/bin/env python
import sys
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    vtkQuadraticEdge,
    vtkQuadraticHexahedron,
    vtkQuadraticPyramid,
    vtkQuadraticQuad,
    vtkQuadraticTetra,
    vtkQuadraticTriangle,
    vtkQuadraticWedge,
    vtkUnstructuredGrid,
)
from vtkmodules.vtkFiltersGeneral import vtkClipDataSet
from vtkmodules.vtkFiltersSources import vtkPlaneSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCellPicker,
    vtkDataSetMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Prevent .pyc files being created.
# Stops the vtk source being polluted
# by .pyc files.
sys.dont_write_bytecode = True

import backdrop

# Contour every quadratic cell type
# Create a scene with one of each cell type.
# QuadraticEdge
edgePoints = vtkPoints()
edgePoints.SetNumberOfPoints(3)
edgePoints.InsertPoint(0, 0, 0, 0)
edgePoints.InsertPoint(1, 1.0, 0, 0)
edgePoints.InsertPoint(2, 0.5, 0.25, 0)
edgeScalars = vtkFloatArray()
edgeScalars.SetNumberOfTuples(3)
edgeScalars.InsertValue(0, 0.0)
edgeScalars.InsertValue(1, 0.0)
edgeScalars.InsertValue(2, 0.9)
aEdge = vtkQuadraticEdge()
aEdge.GetPointIds().SetId(0, 0)
aEdge.GetPointIds().SetId(1, 1)
aEdge.GetPointIds().SetId(2, 2)
aEdgeGrid = vtkUnstructuredGrid()
aEdgeGrid.Allocate(1, 1)
aEdgeGrid.InsertNextCell(aEdge.GetCellType(), aEdge.GetPointIds())
aEdgeGrid.SetPoints(edgePoints)
aEdgeGrid.GetPointData().SetScalars(edgeScalars)
aEdgeMapper = vtkDataSetMapper()
aEdgeMapper.SetInputData(aEdgeGrid)
aEdgeMapper.ScalarVisibilityOff()
aEdgeActor = vtkActor()
aEdgeActor.SetMapper(aEdgeMapper)
aEdgeActor.GetProperty().SetRepresentationToWireframe()
aEdgeActor.GetProperty().SetAmbient(1.0)

# Quadratic triangle
triPoints = vtkPoints()
triPoints.SetNumberOfPoints(6)
triPoints.InsertPoint(0, 0.0, 0.0, 0.0)
triPoints.InsertPoint(1, 1.0, 0.0, 0.0)
triPoints.InsertPoint(2, 0.5, 0.8, 0.0)
triPoints.InsertPoint(3, 0.5, 0.0, 0.0)
triPoints.InsertPoint(4, 0.75, 0.4, 0.0)
triPoints.InsertPoint(5, 0.25, 0.4, 0.0)
triScalars = vtkFloatArray()
triScalars.SetNumberOfTuples(6)
triScalars.InsertValue(0, 0.0)
triScalars.InsertValue(1, 0.0)
triScalars.InsertValue(2, 0.0)
triScalars.InsertValue(3, 1.0)
triScalars.InsertValue(4, 0.0)
triScalars.InsertValue(5, 0.0)
aTri = vtkQuadraticTriangle()
aTri.GetPointIds().SetId(0, 0)
aTri.GetPointIds().SetId(1, 1)
aTri.GetPointIds().SetId(2, 2)
aTri.GetPointIds().SetId(3, 3)
aTri.GetPointIds().SetId(4, 4)
aTri.GetPointIds().SetId(5, 5)
aTriGrid = vtkUnstructuredGrid()
aTriGrid.Allocate(1, 1)
aTriGrid.InsertNextCell(aTri.GetCellType(), aTri.GetPointIds())
aTriGrid.SetPoints(triPoints)
aTriGrid.GetPointData().SetScalars(triScalars)
aTriMapper = vtkDataSetMapper()
aTriMapper.SetInputData(aTriGrid)
aTriMapper.ScalarVisibilityOff()
aTriActor = vtkActor()
aTriActor.SetMapper(aTriMapper)
aTriActor.GetProperty().SetRepresentationToWireframe()
aTriActor.GetProperty().SetAmbient(1.0)

# Quadratic quadrilateral
quadPoints = vtkPoints()
quadPoints.SetNumberOfPoints(8)
quadPoints.InsertPoint(0, 0.0, 0.0, 0.0)
quadPoints.InsertPoint(1, 1.0, 0.0, 0.0)
quadPoints.InsertPoint(2, 1.0, 1.0, 0.0)
quadPoints.InsertPoint(3, 0.0, 1.0, 0.0)
quadPoints.InsertPoint(4, 0.5, 0.0, 0.0)
quadPoints.InsertPoint(5, 1.0, 0.5, 0.0)
quadPoints.InsertPoint(6, 0.5, 1.0, 0.0)
quadPoints.InsertPoint(7, 0.0, 0.5, 0.0)
quadScalars = vtkFloatArray()
quadScalars.SetNumberOfTuples(8)
quadScalars.InsertValue(0, 0.0)
quadScalars.InsertValue(1, 0.0)
quadScalars.InsertValue(2, 1.0)
quadScalars.InsertValue(3, 1.0)
quadScalars.InsertValue(4, 1.0)
quadScalars.InsertValue(5, 0.0)
quadScalars.InsertValue(6, 0.0)
quadScalars.InsertValue(7, 0.0)
aQuad = vtkQuadraticQuad()
aQuad.GetPointIds().SetId(0, 0)
aQuad.GetPointIds().SetId(1, 1)
aQuad.GetPointIds().SetId(2, 2)
aQuad.GetPointIds().SetId(3, 3)
aQuad.GetPointIds().SetId(4, 4)
aQuad.GetPointIds().SetId(5, 5)
aQuad.GetPointIds().SetId(6, 6)
aQuad.GetPointIds().SetId(7, 7)
aQuadGrid = vtkUnstructuredGrid()
aQuadGrid.Allocate(1, 1)
aQuadGrid.InsertNextCell(aQuad.GetCellType(), aQuad.GetPointIds())
aQuadGrid.SetPoints(quadPoints)
aQuadGrid.GetPointData().SetScalars(quadScalars)
aQuadMapper = vtkDataSetMapper()
aQuadMapper.SetInputData(aQuadGrid)
aQuadMapper.ScalarVisibilityOff()
aQuadActor = vtkActor()
aQuadActor.SetMapper(aQuadMapper)
aQuadActor.GetProperty().SetRepresentationToWireframe()
aQuadActor.GetProperty().SetAmbient(1.0)

# Quadratic tetrahedron
tetPoints = vtkPoints()
tetPoints.SetNumberOfPoints(10)
tetPoints.InsertPoint(0, 0.0, 0.0, 0.0)
tetPoints.InsertPoint(1, 1.0, 0.0, 0.0)
tetPoints.InsertPoint(2, 0.5, 0.8, 0.0)
tetPoints.InsertPoint(3, 0.5, 0.4, 1.0)
tetPoints.InsertPoint(4, 0.5, 0.0, 0.0)
tetPoints.InsertPoint(5, 0.75, 0.4, 0.0)
tetPoints.InsertPoint(6, 0.25, 0.4, 0.0)
tetPoints.InsertPoint(7, 0.25, 0.2, 0.5)
tetPoints.InsertPoint(8, 0.75, 0.2, 0.5)
tetPoints.InsertPoint(9, 0.50, 0.6, 0.5)
tetScalars = vtkFloatArray()
tetScalars.SetNumberOfTuples(10)
tetScalars.InsertValue(0, 1.0)
tetScalars.InsertValue(1, 1.0)
tetScalars.InsertValue(2, 1.0)
tetScalars.InsertValue(3, 1.0)
tetScalars.InsertValue(4, 0.0)
tetScalars.InsertValue(5, 0.0)
tetScalars.InsertValue(6, 0.0)
tetScalars.InsertValue(7, 0.0)
tetScalars.InsertValue(8, 0.0)
tetScalars.InsertValue(9, 0.0)
aTet = vtkQuadraticTetra()
aTet.GetPointIds().SetId(0, 0)
aTet.GetPointIds().SetId(1, 1)
aTet.GetPointIds().SetId(2, 2)
aTet.GetPointIds().SetId(3, 3)
aTet.GetPointIds().SetId(4, 4)
aTet.GetPointIds().SetId(5, 5)
aTet.GetPointIds().SetId(6, 6)
aTet.GetPointIds().SetId(7, 7)
aTet.GetPointIds().SetId(8, 8)
aTet.GetPointIds().SetId(9, 9)
aTetGrid = vtkUnstructuredGrid()
aTetGrid.Allocate(1, 1)
aTetGrid.InsertNextCell(aTet.GetCellType(), aTet.GetPointIds())
aTetGrid.SetPoints(tetPoints)
aTetGrid.GetPointData().SetScalars(tetScalars)
aTetMapper = vtkDataSetMapper()
aTetMapper.SetInputData(aTetGrid)
aTetMapper.ScalarVisibilityOff()
aTetActor = vtkActor()
aTetActor.SetMapper(aTetMapper)
aTetActor.GetProperty().SetRepresentationToWireframe()
aTetActor.GetProperty().SetAmbient(1.0)

# Quadratic hexahedron
hexPoints = vtkPoints()
hexPoints.SetNumberOfPoints(20)
hexPoints.InsertPoint(0, 0, 0, 0)
hexPoints.InsertPoint(1, 1, 0, 0)
hexPoints.InsertPoint(2, 1, 1, 0)
hexPoints.InsertPoint(3, 0, 1, 0)
hexPoints.InsertPoint(4, 0, 0, 1)
hexPoints.InsertPoint(5, 1, 0, 1)
hexPoints.InsertPoint(6, 1, 1, 1)
hexPoints.InsertPoint(7, 0, 1, 1)
hexPoints.InsertPoint(8, 0.5, 0, 0)
hexPoints.InsertPoint(9, 1, 0.5, 0)
hexPoints.InsertPoint(10, 0.5, 1, 0)
hexPoints.InsertPoint(11, 0, 0.5, 0)
hexPoints.InsertPoint(12, 0.5, 0, 1)
hexPoints.InsertPoint(13, 1, 0.5, 1)
hexPoints.InsertPoint(14, 0.5, 1, 1)
hexPoints.InsertPoint(15, 0, 0.5, 1)
hexPoints.InsertPoint(16, 0, 0, 0.5)
hexPoints.InsertPoint(17, 1, 0, 0.5)
hexPoints.InsertPoint(18, 1, 1, 0.5)
hexPoints.InsertPoint(19, 0, 1, 0.5)
hexScalars = vtkFloatArray()
hexScalars.SetNumberOfTuples(20)
hexScalars.InsertValue(0, 1.0)
hexScalars.InsertValue(1, 1.0)
hexScalars.InsertValue(2, 1.0)
hexScalars.InsertValue(3, 1.0)
hexScalars.InsertValue(4, 1.0)
hexScalars.InsertValue(5, 1.0)
hexScalars.InsertValue(6, 1.0)
hexScalars.InsertValue(7, 1.0)
hexScalars.InsertValue(8, 0.0)
hexScalars.InsertValue(9, 0.0)
hexScalars.InsertValue(10, 0.0)
hexScalars.InsertValue(11, 0.0)
hexScalars.InsertValue(12, 0.0)
hexScalars.InsertValue(13, 0.0)
hexScalars.InsertValue(14, 0.0)
hexScalars.InsertValue(15, 0.0)
hexScalars.InsertValue(16, 0.0)
hexScalars.InsertValue(17, 0.0)
hexScalars.InsertValue(18, 0.0)
hexScalars.InsertValue(19, 0.0)
aHex = vtkQuadraticHexahedron()
aHex.GetPointIds().SetId(0, 0)
aHex.GetPointIds().SetId(1, 1)
aHex.GetPointIds().SetId(2, 2)
aHex.GetPointIds().SetId(3, 3)
aHex.GetPointIds().SetId(4, 4)
aHex.GetPointIds().SetId(5, 5)
aHex.GetPointIds().SetId(6, 6)
aHex.GetPointIds().SetId(7, 7)
aHex.GetPointIds().SetId(8, 8)
aHex.GetPointIds().SetId(9, 9)
aHex.GetPointIds().SetId(10, 10)
aHex.GetPointIds().SetId(11, 11)
aHex.GetPointIds().SetId(12, 12)
aHex.GetPointIds().SetId(13, 13)
aHex.GetPointIds().SetId(14, 14)
aHex.GetPointIds().SetId(15, 15)
aHex.GetPointIds().SetId(16, 16)
aHex.GetPointIds().SetId(17, 17)
aHex.GetPointIds().SetId(18, 18)
aHex.GetPointIds().SetId(19, 19)
aHexGrid = vtkUnstructuredGrid()
aHexGrid.Allocate(1, 1)
aHexGrid.InsertNextCell(aHex.GetCellType(), aHex.GetPointIds())
aHexGrid.SetPoints(hexPoints)
aHexGrid.GetPointData().SetScalars(hexScalars)
aHexMapper = vtkDataSetMapper()
aHexMapper.SetInputData(aHexGrid)
aHexMapper.ScalarVisibilityOff()
aHexActor = vtkActor()
aHexActor.SetMapper(aHexMapper)
aHexActor.GetProperty().SetRepresentationToWireframe()
aHexActor.GetProperty().SetAmbient(1.0)

# Quadratic wedge
wedgePoints = vtkPoints()
wedgePoints.SetNumberOfPoints(15)
wedgePoints.InsertPoint(0, 0, 0, 0)
wedgePoints.InsertPoint(1, 1, 0, 0)
wedgePoints.InsertPoint(2, 0, 1, 0)
wedgePoints.InsertPoint(3, 0, 0, 1)
wedgePoints.InsertPoint(4, 1, 0, 1)
wedgePoints.InsertPoint(5, 0, 1, 1)
wedgePoints.InsertPoint(6, 0.5, 0, 0)
wedgePoints.InsertPoint(7, 0.5, 0.5, 0)
wedgePoints.InsertPoint(8, 0, 0.5, 0)
wedgePoints.InsertPoint(9, 0.5, 0, 1)
wedgePoints.InsertPoint(10, 0.5, 0.5, 1)
wedgePoints.InsertPoint(11, 0, 0.5, 1)
wedgePoints.InsertPoint(12, 0, 0, 0.5)
wedgePoints.InsertPoint(13, 1, 0, 0.5)
wedgePoints.InsertPoint(14, 0, 1, 0.5)
wedgeScalars = vtkFloatArray()
wedgeScalars.SetNumberOfTuples(15)
wedgeScalars.InsertValue(0, 1.0)
wedgeScalars.InsertValue(1, 1.0)
wedgeScalars.InsertValue(2, 1.0)
wedgeScalars.InsertValue(3, 1.0)
wedgeScalars.InsertValue(4, 1.0)
wedgeScalars.InsertValue(5, 1.0)
wedgeScalars.InsertValue(6, 1.0)
wedgeScalars.InsertValue(7, 1.0)
wedgeScalars.InsertValue(8, 0.0)
wedgeScalars.InsertValue(9, 0.0)
wedgeScalars.InsertValue(10, 0.0)
wedgeScalars.InsertValue(11, 0.0)
wedgeScalars.InsertValue(12, 0.0)
wedgeScalars.InsertValue(13, 0.0)
wedgeScalars.InsertValue(14, 0.0)
aWedge = vtkQuadraticWedge()
aWedge.GetPointIds().SetId(0, 0)
aWedge.GetPointIds().SetId(1, 1)
aWedge.GetPointIds().SetId(2, 2)
aWedge.GetPointIds().SetId(3, 3)
aWedge.GetPointIds().SetId(4, 4)
aWedge.GetPointIds().SetId(5, 5)
aWedge.GetPointIds().SetId(6, 6)
aWedge.GetPointIds().SetId(7, 7)
aWedge.GetPointIds().SetId(8, 8)
aWedge.GetPointIds().SetId(9, 9)
aWedge.GetPointIds().SetId(10, 10)
aWedge.GetPointIds().SetId(11, 11)
aWedge.GetPointIds().SetId(12, 12)
aWedge.GetPointIds().SetId(13, 13)
aWedge.GetPointIds().SetId(14, 14)
aWedgeGrid = vtkUnstructuredGrid()
aWedgeGrid.Allocate(1, 1)
aWedgeGrid.InsertNextCell(aWedge.GetCellType(), aWedge.GetPointIds())
aWedgeGrid.SetPoints(wedgePoints)
aWedgeGrid.GetPointData().SetScalars(wedgeScalars)
wedgeContours = vtkClipDataSet()
wedgeContours.SetInputData(aWedgeGrid)
wedgeContours.SetValue(0.5)
aWedgeContourMapper = vtkDataSetMapper()
aWedgeContourMapper.SetInputConnection(wedgeContours.GetOutputPort())
aWedgeContourMapper.ScalarVisibilityOff()
aWedgeMapper = vtkDataSetMapper()
aWedgeMapper.SetInputData(aWedgeGrid)
aWedgeMapper.ScalarVisibilityOff()
aWedgeActor = vtkActor()
aWedgeActor.SetMapper(aWedgeMapper)
aWedgeActor.GetProperty().SetRepresentationToWireframe()
aWedgeActor.GetProperty().SetAmbient(1.0)
aWedgeContourActor = vtkActor()
aWedgeContourActor.SetMapper(aWedgeContourMapper)
aWedgeContourActor.GetProperty().SetAmbient(1.0)

# Quadratic pyramid
pyraPoints = vtkPoints()
pyraPoints.SetNumberOfPoints(13)
pyraPoints.InsertPoint(0, 0, 0, 0)
pyraPoints.InsertPoint(1, 1, 0, 0)
pyraPoints.InsertPoint(2, 1, 1, 0)
pyraPoints.InsertPoint(3, 0, 1, 0)
pyraPoints.InsertPoint(4, 0, 0, 1)
pyraPoints.InsertPoint(5, 0.5, 0, 0)
pyraPoints.InsertPoint(6, 1, 0.5, 0)
pyraPoints.InsertPoint(7, 0.5, 1, 0)
pyraPoints.InsertPoint(8, 0, 0.5, 0)
pyraPoints.InsertPoint(9, 0, 0, 0.5)
pyraPoints.InsertPoint(10, 0.5, 0, 0.5)
pyraPoints.InsertPoint(11, 0.5, 0.5, 0.5)
pyraPoints.InsertPoint(12, 0, 0.5, 0.5)
pyraScalars = vtkFloatArray()
pyraScalars.SetNumberOfTuples(13)
pyraScalars.InsertValue(0, 1.0)
pyraScalars.InsertValue(1, 1.0)
pyraScalars.InsertValue(2, 1.0)
pyraScalars.InsertValue(3, 1.0)
pyraScalars.InsertValue(4, 1.0)
pyraScalars.InsertValue(5, 1.0)
pyraScalars.InsertValue(6, 1.0)
pyraScalars.InsertValue(7, 1.0)
pyraScalars.InsertValue(8, 0.0)
pyraScalars.InsertValue(9, 0.0)
pyraScalars.InsertValue(10, 0.0)
pyraScalars.InsertValue(11, 0.0)
pyraScalars.InsertValue(12, 0.0)
aPyramid = vtkQuadraticPyramid()
aPyramid.GetPointIds().SetId(0, 0)
aPyramid.GetPointIds().SetId(1, 1)
aPyramid.GetPointIds().SetId(2, 2)
aPyramid.GetPointIds().SetId(3, 3)
aPyramid.GetPointIds().SetId(4, 4)
aPyramid.GetPointIds().SetId(5, 5)
aPyramid.GetPointIds().SetId(6, 6)
aPyramid.GetPointIds().SetId(7, 7)
aPyramid.GetPointIds().SetId(8, 8)
aPyramid.GetPointIds().SetId(9, 9)
aPyramid.GetPointIds().SetId(10, 10)
aPyramid.GetPointIds().SetId(11, 11)
aPyramid.GetPointIds().SetId(12, 12)
aPyramidGrid = vtkUnstructuredGrid()
aPyramidGrid.Allocate(1, 1)
aPyramidGrid.InsertNextCell(aPyramid.GetCellType(), aPyramid.GetPointIds())
aPyramidGrid.SetPoints(pyraPoints)
aPyramidGrid.GetPointData().SetScalars(pyraScalars)
pyraContours = vtkClipDataSet()
pyraContours.SetInputData(aPyramidGrid)
pyraContours.SetValue(0.5)
aPyramidContourMapper = vtkDataSetMapper()
aPyramidContourMapper.SetInputConnection(pyraContours.GetOutputPort())
aPyramidContourMapper.ScalarVisibilityOff()
aPyramidMapper = vtkDataSetMapper()
aPyramidMapper.SetInputData(aPyramidGrid)
aPyramidMapper.ScalarVisibilityOff()
aPyramidActor = vtkActor()
aPyramidActor.SetMapper(aPyramidMapper)
aPyramidActor.GetProperty().SetRepresentationToWireframe()
aPyramidActor.GetProperty().SetAmbient(1.0)
aPyramidContourActor = vtkActor()
aPyramidContourActor.SetMapper(aPyramidContourMapper)
aPyramidContourActor.GetProperty().SetAmbient(1.0)

# Create the rendering related stuff.
# Since some of our actors are a single vertex, we need to remove all
# cullers so the single vertex actors will render
ren1 = vtkRenderer()
ren1.GetCullers().RemoveAllItems()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
ren1.SetBackground(.1, .2, .3)

renWin.SetSize(400, 200)

# specify properties
ren1.AddActor(aEdgeActor)
ren1.AddActor(aTriActor)
ren1.AddActor(aQuadActor)
ren1.AddActor(aTetActor)
ren1.AddActor(aHexActor)
ren1.AddActor(aWedgeActor)
ren1.AddActor(aPyramidActor)

# places everyone!!
aTriActor.AddPosition(2, 0, 0)
aQuadActor.AddPosition(4, 0, 0)
aTetActor.AddPosition(6, 0, 0)
aHexActor.AddPosition(8, 0, 0)
aWedgeActor.AddPosition(10, 0, 0)
aPyramidActor.AddPosition(12, 0, 0)
[base, back, left] = backdrop.BuildBackdrop(-1, 15, -1, 4, -1, 2, .1)
ren1.AddActor(base)
base.GetProperty().SetDiffuseColor(.2, .2, .2)
ren1.AddActor(left)
left.GetProperty().SetDiffuseColor(.2, .2, .2)
ren1.AddActor(back)
back.GetProperty().SetDiffuseColor(.2, .2, .2)
ren1.ResetCamera()
ren1.GetActiveCamera().Dolly(2.5)
ren1.ResetCameraClippingRange()
renWin.Render()

# create a little scorecard above each of the cells. These are displayed
# if a ray cast hits the cell, otherwise they are not shown.
pm = vtkPlaneSource()
pm.SetXResolution(1)
pm.SetYResolution(1)
pmapper = vtkPolyDataMapper()
pmapper.SetInputConnection(pm.GetOutputPort())

# now try intersecting rays with the cell
cellPicker = vtkCellPicker()
edgeCheck = vtkActor()
edgeCheck.SetMapper(pmapper)
edgeCheck.AddPosition(0.5, 2.5, 0)
cellPicker.Pick(87, 71, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aEdge.GetCellType()):
        ren1.AddActor(edgeCheck)

triCheck = vtkActor()
triCheck.SetMapper(pmapper)
triCheck.AddPosition(2.5, 2.5, 0)
cellPicker.Pick(139, 72, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aTri.GetCellType()):
        ren1.AddActor(triCheck)

quadCheck = vtkActor()
quadCheck.SetMapper(pmapper)
quadCheck.AddPosition(4.5, 2.5, 0)
cellPicker.Pick(192, 78, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aQuad.GetCellType()):
        ren1.AddActor(quadCheck)

tetCheck = vtkActor()
tetCheck.SetMapper(pmapper)
tetCheck.AddPosition(6.5, 2.5, 0)
cellPicker.Pick(233, 70, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aTet.GetCellType()):
        ren1.AddActor(tetCheck)

hexCheck = vtkActor()
hexCheck.SetMapper(pmapper)
hexCheck.AddPosition(8.5, 2.5, 0)
cellPicker.Pick(287, 80, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aHex.GetCellType()):
        ren1.AddActor(hexCheck)

wedgeCheck = vtkActor()
wedgeCheck.SetMapper(pmapper)
wedgeCheck.AddPosition(10.5, 2.5, 0)
cellPicker.Pick(287, 80, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aWedge.GetCellType()):
        ren1.AddActor(wedgeCheck)

pyraCheck = vtkActor()
pyraCheck.SetMapper(pmapper)
pyraCheck.AddPosition(12.5, 2.5, 0)
cellPicker.Pick(287, 80, 0, ren1)
cellId = cellPicker.GetCellId()
if (cellId != -1):
    if (pmapper.GetInput().GetCellType(cellId)==aPyramid.GetCellType()):
        ren1.AddActor(pyraCheck)

# render the image
#
iren.Initialize()
#iren.Start()



# SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
# SPDX-License-Identifier: BSD-3-Clause
import sys
import re
from pathlib import Path
from vtkmodules.test import Testing
from vtkmodules.vtkCommonCore import *
from vtkmodules.vtkCommonDataModel import *
from vtkmodules.vtkInteractionStyle import *
from vtkmodules.vtkIOCellGrid import *
from vtkmodules.vtkFiltersCellGrid import *
from vtkmodules.vtkFiltersSources import *
from vtkmodules.vtkRenderingAnnotation import *
from vtkmodules.vtkRenderingCore import *
from vtkmodules.vtkRenderingCellGrid import *

import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()


# Register render responder for DG cells
vtkRenderingCellGrid.RegisterCellsAndResponders()

events = """# StreamVersion 1.2
ExposeEvent 0 479 0 0 0 0 0
RenderEvent 0 479 0 0 0 0 0
EnterEvent 496 4 0 0 0 0 0
MouseMoveEvent 496 4 0 0 0 0 0
MouseMoveEvent 239 145 0 0 0 0 0
KeyPressEvent 239 145 0 114 1 r 0
CharEvent 239 145 0 114 1 r 0
MouseMoveEvent 239 145 0 0 0 r 0
MouseMoveEvent 245 155 0 0 0 r 0
KeyReleaseEvent 245 155 0 114 1 r 0
MouseMoveEvent 246 157 0 0 0 r 0
MouseMoveEvent 251 172 0 0 0 r 0
LeftButtonPressEvent 251 172 0 0 0 r 0
MouseMoveEvent 252 172 0 0 0 r 0
MouseMoveEvent 277 150 0 0 0 r 0
LeftButtonReleaseEvent 277 150 0 0 0 r 0
StartPickEvent 277 150 0 0 0 r 0
EndPickEvent 277 150 0 0 0 r 0
RenderEvent 277 150 0 0 0 r 0
MouseMoveEvent 277 150 0 0 0 r 0
MouseMoveEvent 291 242 0 0 0 r 0
LeftButtonPressEvent 291 242 0 0 0 r 0
MouseMoveEvent 293 242 0 0 0 r 0
MouseMoveEvent 340 201 0 0 0 r 0
LeftButtonReleaseEvent 340 201 0 0 0 r 0
StartPickEvent 340 201 0 0 0 r 0
EndPickEvent 340 201 0 0 0 r 0
RenderEvent 340 201 0 0 0 r 0
MouseMoveEvent 339 201 0 0 0 r 0
MouseMoveEvent 264 191 0 0 0 r 0
LeftButtonPressEvent 264 191 0 0 0 r 0
MouseMoveEvent 265 191 0 0 0 r 0
MouseMoveEvent 339 141 0 0 0 r 0
MouseMoveEvent 340 141 0 0 0 r 0
LeftButtonReleaseEvent 340 141 0 0 0 r 0
StartPickEvent 340 141 0 0 0 r 0
EndPickEvent 340 141 0 0 0 r 0
RenderEvent 340 141 0 0 0 r 0
MouseMoveEvent 339 142 0 0 0 r 0
MouseMoveEvent 265 194 0 0 0 r 0
LeftButtonPressEvent 265 194 0 0 0 r 0
MouseMoveEvent 265 194 0 0 0 r 0
MouseMoveEvent 211 249 0 0 0 r 0
LeftButtonReleaseEvent 211 249 0 0 0 r 0
StartPickEvent 211 249 0 0 0 r 0
EndPickEvent 211 249 0 0 0 r 0
RenderEvent 211 249 0 0 0 r 0
MouseMoveEvent 211 248 0 0 0 r 0
MouseMoveEvent 147 403 0 0 0 r 0
LeftButtonPressEvent 147 403 0 0 0 r 0
MouseMoveEvent 147 401 0 0 0 r 0
MouseMoveEvent 599 41 0 0 0 r 0
LeftButtonReleaseEvent 599 41 0 0 0 r 0
StartPickEvent 599 41 0 0 0 r 0
EndPickEvent 599 41 0 0 0 r 0
RenderEvent 599 41 0 0 0 r 0
MouseMoveEvent 595 42 0 0 0 r 0
MouseMoveEvent 607 7 0 0 0 r 0
LeaveEvent 608 -4 0 0 0 r 0"""

record_events = False


class TestCellGridRenderedAreaPickerWithPolyData(Testing.vtkTest):

    def test(self):
        data_file = Path(VTK_DATA_ROOT).joinpath(
            'Data', 'dgQuadraticQuadrilaterals.dg')
        reader = vtkCellGridReader(file_name=data_file)

        compute_sides = vtkCellGridComputeSides(
            output_dimension_control=vtkCellGridSidesQuery.NextLowestDimension,
            preserve_renderable_inputs=False,
            omit_sides_for_renderable_inputs=False,)
        mapper_sides = vtkCellGridMapper()
        reader >> compute_sides >> mapper_sides

        mapper = vtkCellGridMapper(array_component=-2,
                                   array_name="scalar2",
                                   scalar_mode=VTK_SCALAR_MODE_USE_CELL_FIELD_DATA,
                                   scalar_visibility=True,)
        reader >> mapper

        actor_sides = vtkActor()
        actor_sides.mapper = mapper_sides
        actor_sides.property.line_width = 4.0

        actor = vtkActor()
        actor.mapper = mapper

        sphere_actor = vtkActor()
        sphere_actor.mapper = (vtkSphereSource() >> vtkPolyDataMapper()).last

        self.expected_selection_nodes = [
            {
                'pick_id': 0,
                'nodes': [
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 26,
                        'ZBUFFER_VALUE': 0.6403792500495911,
                        'CELLGRID_CELL_TYPE_INDEX': -1,
                        'PROP': sphere_actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': -1,
                        'PROP_ID': 2,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            2,
                            44
                        ]
                    }
                ]
            },
            {
                'pick_id': 1,
                'nodes': [
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 2100,
                        'ZBUFFER_VALUE': 0.7080743908882141,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 0,
                        'PROP_ID': 0,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0
                        ]
                    }
                ]
            },
            {
                'pick_id': 2,
                'nodes': [
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 70,
                        'ZBUFFER_VALUE': 0.6403792500495911,
                        'CELLGRID_CELL_TYPE_INDEX': -1,
                        'PROP': sphere_actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': -1,
                        'PROP_ID': 2,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            2,
                            3,
                            4,
                            9,
                            45
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 176,
                        'ZBUFFER_VALUE': 0.6976379156112671,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor_sides,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 1,
                        'PROP_ID': 1,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 1130,
                        'ZBUFFER_VALUE': 0.6987160444259644,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 0,
                        'PROP_ID': 0,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0
                        ]
                    }
                ]
            },
            {
                'pick_id': 3,
                'nodes': [
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 96,
                        'ZBUFFER_VALUE': 0.6588415503501892,
                        'CELLGRID_CELL_TYPE_INDEX': -1,
                        'PROP': sphere_actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': -1,
                        'PROP_ID': 2,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            15,
                            16,
                            17,
                            21,
                            22,
                            23
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 469,
                        'ZBUFFER_VALUE': 0.7515520453453064,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 0,
                        'PROP_ID': 0,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 69,
                        'ZBUFFER_VALUE': 0.7761813402175903,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor_sides,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 1,
                        'PROP_ID': 1,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            2
                        ]
                    }
                ]
            },
            {
                'pick_id': 4,
                'nodes': [
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 2737,
                        'ZBUFFER_VALUE': 0.3899713456630707,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor_sides,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 1,
                        'PROP_ID': 1,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0,
                            1,
                            2,
                            3,
                            4,
                            5
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 41259,
                        'ZBUFFER_VALUE': 0.4132111966609955,
                        'CELLGRID_CELL_TYPE_INDEX': 0,
                        'PROP': actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': 0,
                        'PROP_ID': 0,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0,
                            1
                        ]
                    },
                    {
                        'COMPOSITE_INDEX': 1,
                        'PIXEL_COUNT': 625,
                        'ZBUFFER_VALUE': 0.6337828636169434,
                        'CELLGRID_CELL_TYPE_INDEX': -1,
                        'PROP': sphere_actor,
                        'CELLGRID_SOURCE_SPECIFICATION_INDEX': -1,
                        'PROP_ID': 2,
                        'FIELD_TYPE': 1,
                        'CONTENT_TYPE': 3,
                        'SelectedIds': [
                            0,
                            2,
                            3,
                            4,
                            8,
                            9,
                            10,
                            11,
                            14,
                            15,
                            16,
                            17,
                            20,
                            21,
                            22,
                            23,
                            26,
                            27,
                            28,
                            29,
                            32,
                            33,
                            34,
                            38,
                            39,
                            40,
                            41,
                            44,
                            45,
                            46,
                            47
                        ]
                    }
                ]
            },]

        renderer = vtkRenderer()
        renderer.AddActor(actor)
        renderer.AddActor(actor_sides)
        renderer.AddActor(sphere_actor)

        window = vtkRenderWindow(size=(640, 480), multi_samples=0)
        window.AddRenderer(renderer)

        interactor = vtkRenderWindowInteractor(
            interactor_style=vtkInteractorStyleRubberBandPick())
        interactor.picker = vtkRenderedAreaPicker()
        interactor.render_window = window
        interactor.AddObserver(vtkCommand.EndPickEvent, self._on_pick_finished)
        recorder = vtkInteractorEventRecorder(interactor=interactor)
        recorder.SetEnabled(True)
        self._pick_event_id = 0
        if record_events:
            recorder.SetFileName("events.txt")
            recorder.Record()
            interactor.Start()
            recorder.Stop()
        else:
            recorder.read_from_input_string = True
            # Scrub away all EndPickEvent(s) from the recorded events
            recorder.input_string = re.sub(
                r'^EndPickEvent.*\n?',
                '', events, flags=re.MULTILINE)
            # Render once so that camera is reset to geometry bounds.
            window.Render()
            recorder.Play()

    def _on_pick_finished(self, interactor, event):
        cursor = interactor.GetEventPosition()
        renderer = interactor.FindPokedRenderer(cursor[0], cursor[1])
        selection = vtkSelection()
        rect = (renderer.pick_x1, renderer.pick_y1,
                renderer.pick_x2, renderer.pick_y2)
        renderer.PickProp(
            *rect,
            # fieldSelection=
            0,
            selection)
        num_nodes = selection.GetNumberOfNodes()
        event_id = self._pick_event_id
        self._pick_event_id += 1
        for i in range(num_nodes):
            node = selection.GetNode(i)
            expected = self.expected_selection_nodes[event_id].get("nodes")[i]
            for k, v in expected.items():
                if k == "SelectedIds":
                    selected_ids_arr = node.selection_data.GetArray(
                        "SelectedIds")
                    selected_ids = [int(selected_ids_arr.GetValue(i)) for i in range(
                        selected_ids_arr.GetNumberOfValues())]
                    self.assertListEqual(v, selected_ids)
                    continue
                vtk_info_key = getattr(vtkSelectionNode, k)()
                expected[k] = node.GetProperties().Get(vtk_info_key)
                if k == "ZBUFFER_VALUE":
                    # More lenient because zbuffer value can vary lightly based on graphics implementations
                    self.assertAlmostEqual(v, node.GetProperties().Get(vtk_info_key), places=5)
                else:
                    self.assertEqual(v, node.GetProperties().Get(vtk_info_key))


if __name__ == "__main__":
    Testing.main([(TestCellGridRenderedAreaPickerWithPolyData,
                   'test')])



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import vtkPiecewiseFunction
from vtkmodules.vtkFiltersCore import (
    vtkContourFilter,
    vtkGlyph3D,
    vtkTubeFilter,
)
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkIOChemistry import vtkGaussianCubeReader
from vtkmodules.vtkImagingCore import vtkImageShiftScale
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCamera,
    vtkColorTransferFunction,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkVolume,
    vtkVolumeProperty,
)
from vtkmodules.vtkRenderingVolume import vtkFixedPointVolumeRayCastMapper
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.vtkRenderingVolumeOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren1)

renWin.SetSize(300, 300)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

camera = vtkCamera()
camera.ParallelProjectionOn()
camera.SetViewUp(0, 1, 0)
camera.SetFocalPoint(12, 10.5, 15)
camera.SetPosition(-70, 15, 34)
camera.ComputeViewPlaneNormal()
ren1.SetActiveCamera(camera)
# Create the reader for the data
# vtkStructuredPointsReader reader
reader = vtkGaussianCubeReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/m4_TotalDensity.cube")
reader.SetHBScale(1.1)
reader.SetBScale(10)
reader.Update()

range = reader.GetGridOutput().GetPointData().GetScalars().GetRange()

min = range[0]
max = range[1]

readerSS = vtkImageShiftScale()
readerSS.SetInputData(reader.GetGridOutput())
readerSS.SetShift(min * -1)
readerSS.SetScale(255 / (max - min))
readerSS.SetOutputScalarTypeToUnsignedChar()

bounds = vtkOutlineFilter()
bounds.SetInputData(reader.GetGridOutput())

boundsMapper = vtkPolyDataMapper()
boundsMapper.SetInputConnection(bounds.GetOutputPort())

boundsActor = vtkActor()
boundsActor.SetMapper(boundsMapper)
boundsActor.GetProperty().SetColor(0, 0, 0)

contour = vtkContourFilter()
contour.SetInputData(reader.GetGridOutput())
contour.GenerateValues(5, 0, .05)

contourMapper = vtkPolyDataMapper()
contourMapper.SetInputConnection(contour.GetOutputPort())
contourMapper.SetScalarRange(0, .1)
contourMapper.GetLookupTable().SetHueRange(0.32, 0)

contourActor = vtkActor()
contourActor.SetMapper(contourMapper)
contourActor.GetProperty().SetOpacity(.5)

# Create transfer mapping scalar value to opacity
opacityTransferFunction = vtkPiecewiseFunction()
opacityTransferFunction.AddPoint(0, 0.01)
opacityTransferFunction.AddPoint(255, 0.35)
opacityTransferFunction.ClampingOn()

# Create transfer mapping scalar value to color
colorTransferFunction = vtkColorTransferFunction()
colorTransferFunction.AddHSVPoint(0.0, 0.66, 1.0, 1.0)
colorTransferFunction.AddHSVPoint(50.0, 0.33, 1.0, 1.0)
colorTransferFunction.AddHSVPoint(100.0, 0.00, 1.0, 1.0)

# The property describes how the data will look
volumeProperty = vtkVolumeProperty()
volumeProperty.SetColor(colorTransferFunction)
volumeProperty.SetScalarOpacity(opacityTransferFunction)
volumeProperty.SetInterpolationTypeToLinear()

# The mapper knows how to render the data
volumeMapper = vtkFixedPointVolumeRayCastMapper()
volumeMapper.SetInputConnection(readerSS.GetOutputPort())

# The volume holds the mapper and the property and
# can be used to position/orient the volume
volume = vtkVolume()
volume.SetMapper(volumeMapper)
volume.SetProperty(volumeProperty)

ren1.AddVolume(volume)

# ren1 AddActor contourActor
ren1.AddActor(boundsActor)

######################################################################
Sphere = vtkSphereSource()
Sphere.SetCenter(0, 0, 0)
Sphere.SetRadius(1)
Sphere.SetThetaResolution(16)
Sphere.SetStartTheta(0)
Sphere.SetEndTheta(360)
Sphere.SetPhiResolution(16)
Sphere.SetStartPhi(0)
Sphere.SetEndPhi(180)

Glyph = vtkGlyph3D()
Glyph.SetInputConnection(reader.GetOutputPort())
Glyph.SetOrient(1)
Glyph.SetColorMode(1)
# Glyph.ScalingOn()
Glyph.SetScaleMode(2)
Glyph.SetScaleFactor(.6)
Glyph.SetSourceConnection(Sphere.GetOutputPort())

AtomsMapper = vtkPolyDataMapper()
AtomsMapper.SetInputConnection(Glyph.GetOutputPort())
AtomsMapper.UseLookupTableScalarRangeOff()
AtomsMapper.SetScalarVisibility(1)
AtomsMapper.SetScalarModeToDefault()

Atoms = vtkActor()
Atoms.SetMapper(AtomsMapper)
Atoms.GetProperty().SetRepresentationToSurface()
Atoms.GetProperty().SetInterpolationToGouraud()
Atoms.GetProperty().SetAmbient(0.15)
Atoms.GetProperty().SetDiffuse(0.85)
Atoms.GetProperty().SetSpecular(0.1)
Atoms.GetProperty().SetSpecularPower(100)
Atoms.GetProperty().SetSpecularColor(1, 1, 1)
Atoms.GetProperty().SetColor(1, 1, 1)

Tube = vtkTubeFilter()
Tube.SetInputConnection(reader.GetOutputPort())
Tube.SetNumberOfSides(16)
Tube.SetCapping(0)
Tube.SetRadius(0.2)
Tube.SetVaryRadius(0)
Tube.SetRadiusFactor(10)

BondsMapper = vtkPolyDataMapper()
BondsMapper.SetInputConnection(Tube.GetOutputPort())
BondsMapper.UseLookupTableScalarRangeOff()
BondsMapper.SetScalarVisibility(1)
BondsMapper.SetScalarModeToDefault()

Bonds = vtkActor()
Bonds.SetMapper(BondsMapper)
Bonds.GetProperty().SetRepresentationToSurface()
Bonds.GetProperty().SetInterpolationToGouraud()
Bonds.GetProperty().SetAmbient(0.15)
Bonds.GetProperty().SetDiffuse(0.85)
Bonds.GetProperty().SetSpecular(0.1)
Bonds.GetProperty().SetSpecularPower(100)
Bonds.GetProperty().SetSpecularColor(1, 1, 1)
Bonds.GetProperty().SetColor(1, 1, 1
                             )
ren1.AddActor(Bonds)
ren1.AddActor(Atoms)
####################################################
ren1.SetBackground(1, 1, 1)
ren1.ResetCamera()

renWin.Render()

def TkCheckAbort(obj=None, event=""):
    if renWin.GetEventPending():
        renWin.SetAbortRender(1)

renWin.AddObserver("AbortCheckEvent", TkCheckAbort)

iren.Initialize()
#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkMath
from vtkmodules.vtkCommonDataModel import vtkSphere
from vtkmodules.vtkCommonSystem import vtkTimerLog
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersPoints import (
    vtkBoundedPointSource,
    vtkFitImplicitFunction,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPointGaussianMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Interpolate onto a volume

# Parameters for debugging
NPts = 1000000
math = vtkMath()
math.RandomSeed(31415)

# create pipeline
#
points = vtkBoundedPointSource()
points.SetNumberOfPoints(NPts)
points.ProduceRandomScalarsOn()
points.ProduceCellOutputOff()
points.Update()

# Create a sphere implicit function
sphere = vtkSphere()
sphere.SetCenter(0.9,0.1,0.1)
sphere.SetRadius(0.33)

# Extract points within sphere
extract = vtkFitImplicitFunction()
extract.SetInputConnection(points.GetOutputPort())
extract.SetImplicitFunction(sphere)
extract.SetThreshold(0.005)

# Time execution
timer = vtkTimerLog()
timer.StartTimer()
extract.Update()
timer.StopTimer()
time = timer.GetElapsedTime()
print("Time to extract points: {0}".format(time))
print("   Number removed: {0}".format(extract.GetNumberOfPointsRemoved()))
print("   Original number of points: {0}".format(NPts))

# First output are the non-outliers
extMapper = vtkPointGaussianMapper()
extMapper.SetInputConnection(extract.GetOutputPort())
extMapper.EmissiveOff()
extMapper.SetScaleFactor(0.0)

extActor = vtkActor()
extActor.SetMapper(extMapper)

# Create an outline
outline = vtkOutlineFilter()
outline.SetInputConnection(points.GetOutputPort())

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)

# Create the RenderWindow, Renderer and both Actors
#
ren0 = vtkRenderer()
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Add the actors to the renderer, set the background and size
#
ren0.AddActor(extActor)
ren0.AddActor(outlineActor)
ren0.SetBackground(0.1, 0.2, 0.4)

renWin.SetSize(250,250)

cam = ren0.GetActiveCamera()
cam.SetFocalPoint(1,1,1)
cam.SetPosition(0,0,0)
ren0.ResetCamera()

ren1.SetActiveCamera(cam)

iren.Initialize()

# render the image
#
renWin.Render()

iren.Start()



#!/usr/bin/env python
import os
from vtkmodules.vtkFiltersCore import (
    vtkDataObjectToDataSetFilter,
    vtkDataSetToDataObjectFilter,
    vtkFieldDataToAttributeDataFilter,
)
from vtkmodules.vtkIOLegacy import (
    vtkDataObjectReader,
    vtkDataObjectWriter,
    vtkPolyDataReader,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This example demonstrates the reading of a field and conversion to PolyData
# The output should be the same as polyEx.tcl.

# Create a reader and write out the field
reader = vtkPolyDataReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/polyEx.vtk")

ds2do = vtkDataSetToDataObjectFilter()
ds2do.SetInputConnection(reader.GetOutputPort())

# NOTE: This test only works if the current directory is writable
#
try:
    channel = open("PolyField.vtk", "wb")
    channel.close()

    writer = vtkDataObjectWriter()
    writer.SetInputConnection(ds2do.GetOutputPort())
    writer.SetFileName("PolyField.vtk")
    writer.Write()

    # create pipeline
    #
    dor = vtkDataObjectReader()
    dor.SetFileName("PolyField.vtk")

    do2ds = vtkDataObjectToDataSetFilter()
    do2ds.SetInputConnection(dor.GetOutputPort())
    do2ds.SetDataSetTypeToPolyData()
    do2ds.SetPointComponent(0, "Points", 0)
    do2ds.SetPointComponent(1, "Points", 1)
    do2ds.SetPointComponent(2, "Points", 2)
    do2ds.SetPolysComponent("Polys", 0)

    fd2ad = vtkFieldDataToAttributeDataFilter()
    fd2ad.SetInputConnection(do2ds.GetOutputPort())
    fd2ad.SetInputFieldToDataObjectField()
    fd2ad.SetOutputAttributeDataToPointData()
    fd2ad.SetScalarComponent(0, "my_scalars", 0)

    mapper = vtkPolyDataMapper()
    mapper.SetInputConnection(fd2ad.GetOutputPort())
    mapper.SetScalarRange(fd2ad.GetOutput().GetScalarRange())

    actor = vtkActor()
    actor.SetMapper(mapper)

    # Create the RenderWindow, Renderer and both Actors
    ren1 = vtkRenderer()
    renWin = vtkRenderWindow()
    renWin.AddRenderer(ren1)
    iren = vtkRenderWindowInteractor()
    iren.SetRenderWindow(renWin)

    ren1.AddActor(actor)
    ren1.SetBackground(1, 1, 1)

    renWin.SetSize(300, 300)

    ren1.ResetCamera()
    cam1 = ren1.GetActiveCamera()
    cam1.SetClippingRange(.348, 17.43)
    cam1.SetPosition(2.92, 2.62, -0.836)
    cam1.SetViewUp(-0.436, -0.067, -0.897)
    cam1.Azimuth(90)

    # render the image
    #
    renWin.Render()

    # cleanup
    #
    try:
        os.remove("PolyField.vtk")
    except OSError:
        pass


#    iren.Start()

except IOError:
    print("Couldn't open PolyField.vtk for writing.")



r"""
This is a script that can be used to run tests that require multiple
executables to be run e.g. those client-server tests.

Usage:
  python vtkTestDriver.py --process exe1 arg11 arg12 ...
                          --process exe2 arg21 arg22 ...
                          --process ...
"""

from __future__ import print_function

import sys
import subprocess
import time

# Extract arguments for each process to execute.
command_lists = []
prev = None
for idx in range(1, len(sys.argv)):
    if sys.argv[idx] == "--process":
        if prev:
            command_lists.append(sys.argv[prev:idx])
        prev = idx+1
if prev <= len(sys.argv):
    command_lists.append(sys.argv[prev:])

procs = []
for cmdlist in command_lists:
    print("Executing '", " ".join(cmdlist), "'", file=sys.stderr)
    proc = subprocess.Popen(cmdlist)
    procs.append(proc)
    # sleep to ensure that the process starts.
    time.sleep(0.1)

# Now wait for each of the processes to terminate.
# If ctest times out, it will kill this process and all subprocesses will be
# terminated anyways, so we don't need to handle timeout specially.
for proc in procs:
    proc.wait()

for proc in procs:
    if proc.returncode != 0:
        print("ERROR: A process exited with error. Test will fail.", file=sys.stderr)
        sys.exit(1) # error
print("All's well!")



#!/usr/bin/env python
# -*- coding: utf-8 -*-



# Test the vtkTensorWidget and vtkTensorRepresentation classes

from vtkmodules.vtkInteractionWidgets import (
    vtkTensorRepresentation,
    vtkTensorWidget,
)
from vtkmodules.vtkRenderingCore import (
    vtkInteractorEventRecorder,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.test.Testing
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# These are the pre-recorded events to drive the test
Recording = \
    "# StreamVersion 1.1\n\
    RenderEvent 0 299 0 0 0 0\n\
    EnterEvent 299 51 0 0 0 0\n\
    MouseMoveEvent 299 51 0 0 0 0\n\
    MouseMoveEvent 297 51 0 0 0 0\n\
    MouseMoveEvent 295 51 0 0 0 0\n\
    MouseMoveEvent 294 51 0 0 0 0\n\
    MouseMoveEvent 293 52 0 0 0 0\n\
    MouseMoveEvent 292 52 0 0 0 0\n\
    MouseMoveEvent 291 52 0 0 0 0\n\
    MouseMoveEvent 290 52 0 0 0 0\n\
    MouseMoveEvent 290 52 0 0 0 0\n\
    MouseMoveEvent 289 52 0 0 0 0\n\
    MouseMoveEvent 288 52 0 0 0 0\n\
    MouseMoveEvent 287 52 0 0 0 0\n\
    MouseMoveEvent 285 52 0 0 0 0\n\
    MouseMoveEvent 283 52 0 0 0 0\n\
    MouseMoveEvent 281 52 0 0 0 0\n\
    MouseMoveEvent 280 52 0 0 0 0\n\
    MouseMoveEvent 279 52 0 0 0 0\n\
    KeyPressEvent 279 52 0 116 1 t\n\
    CharEvent 279 52 0 116 1 t\n\
    KeyReleaseEvent 279 52 0 116 1 t\n\
    MouseMoveEvent 278 52 0 0 0 t\n\
    MouseMoveEvent 277 52 0 0 0 t\n\
    MouseMoveEvent 276 52 0 0 0 t\n\
    MouseMoveEvent 275 52 0 0 0 t\n\
    MouseMoveEvent 274 52 0 0 0 t\n\
    MouseMoveEvent 273 52 0 0 0 t\n\
    MouseMoveEvent 273 52 0 0 0 t\n\
    LeftButtonPressEvent 273 52 0 0 0 t\n\
    StartInteractionEvent 273 52 0 0 0 t\n\
    MouseMoveEvent 273 52 0 0 0 t\n\
    RenderEvent 273 52 0 0 0 t\n\
    InteractionEvent 273 52 0 0 0 t\n\
    MouseMoveEvent 274 52 0 0 0 t\n\
    RenderEvent 274 52 0 0 0 t\n\
    InteractionEvent 274 52 0 0 0 t\n\
    MouseMoveEvent 275 52 0 0 0 t\n\
    RenderEvent 275 52 0 0 0 t\n\
    InteractionEvent 275 52 0 0 0 t\n\
    MouseMoveEvent 276 51 0 0 0 t\n\
    RenderEvent 276 51 0 0 0 t\n\
    InteractionEvent 276 51 0 0 0 t\n\
    MouseMoveEvent 277 51 0 0 0 t\n\
    RenderEvent 277 51 0 0 0 t\n\
    InteractionEvent 277 51 0 0 0 t\n\
    MouseMoveEvent 277 51 0 0 0 t\n\
    RenderEvent 277 51 0 0 0 t\n\
    InteractionEvent 277 51 0 0 0 t\n\
    MouseMoveEvent 278 51 0 0 0 t\n\
    RenderEvent 278 51 0 0 0 t\n\
    InteractionEvent 278 51 0 0 0 t\n\
    MouseMoveEvent 279 51 0 0 0 t\n\
    RenderEvent 279 51 0 0 0 t\n\
    InteractionEvent 279 51 0 0 0 t\n\
    MouseMoveEvent 280 51 0 0 0 t\n\
    RenderEvent 280 51 0 0 0 t\n\
    InteractionEvent 280 51 0 0 0 t\n\
    MouseMoveEvent 282 50 0 0 0 t\n\
    RenderEvent 282 50 0 0 0 t\n\
    InteractionEvent 282 50 0 0 0 t\n\
    MouseMoveEvent 283 50 0 0 0 t\n\
    RenderEvent 283 50 0 0 0 t\n\
    InteractionEvent 283 50 0 0 0 t\n\
    MouseMoveEvent 284 49 0 0 0 t\n\
    RenderEvent 284 49 0 0 0 t\n\
    InteractionEvent 284 49 0 0 0 t\n\
    MouseMoveEvent 285 49 0 0 0 t\n\
    RenderEvent 285 49 0 0 0 t\n\
    InteractionEvent 285 49 0 0 0 t\n\
    MouseMoveEvent 288 49 0 0 0 t\n\
    RenderEvent 288 49 0 0 0 t\n\
    InteractionEvent 288 49 0 0 0 t\n\
    MouseMoveEvent 290 49 0 0 0 t\n\
    RenderEvent 290 49 0 0 0 t\n\
    InteractionEvent 290 49 0 0 0 t\n\
    MouseMoveEvent 292 49 0 0 0 t\n\
    RenderEvent 292 49 0 0 0 t\n\
    InteractionEvent 292 49 0 0 0 t\n\
    MouseMoveEvent 293 49 0 0 0 t\n\
    RenderEvent 293 49 0 0 0 t\n\
    InteractionEvent 293 49 0 0 0 t\n\
    MouseMoveEvent 294 49 0 0 0 t\n\
    RenderEvent 294 49 0 0 0 t\n\
    InteractionEvent 294 49 0 0 0 t\n\
    MouseMoveEvent 295 49 0 0 0 t\n\
    RenderEvent 295 49 0 0 0 t\n\
    InteractionEvent 295 49 0 0 0 t\n\
    MouseMoveEvent 297 49 0 0 0 t\n\
    RenderEvent 297 49 0 0 0 t\n\
    InteractionEvent 297 49 0 0 0 t\n\
    MouseMoveEvent 298 49 0 0 0 t\n\
    RenderEvent 298 49 0 0 0 t\n\
    InteractionEvent 298 49 0 0 0 t\n\
    MouseMoveEvent 299 49 0 0 0 t\n\
    RenderEvent 299 49 0 0 0 t\n\
    InteractionEvent 299 49 0 0 0 t\n\
    MouseMoveEvent 300 49 0 0 0 t\n\
    RenderEvent 300 49 0 0 0 t\n\
    InteractionEvent 300 49 0 0 0 t\n\
    LeaveEvent 300 49 0 0 0 t\n\
    MouseMoveEvent 302 49 0 0 0 t\n\
    RenderEvent 302 49 0 0 0 t\n\
    InteractionEvent 302 49 0 0 0 t\n\
    MouseMoveEvent 303 50 0 0 0 t\n\
    RenderEvent 303 50 0 0 0 t\n\
    InteractionEvent 303 50 0 0 0 t\n\
    MouseMoveEvent 305 51 0 0 0 t\n\
    RenderEvent 305 51 0 0 0 t\n\
    InteractionEvent 305 51 0 0 0 t\n\
    MouseMoveEvent 306 51 0 0 0 t\n\
    RenderEvent 306 51 0 0 0 t\n\
    InteractionEvent 306 51 0 0 0 t\n\
    MouseMoveEvent 306 51 0 0 0 t\n\
    RenderEvent 306 51 0 0 0 t\n\
    InteractionEvent 306 51 0 0 0 t\n\
    LeftButtonReleaseEvent 306 51 0 0 0 t\n\
    EndInteractionEvent 306 51 0 0 0 t\n\
    RenderEvent 306 51 0 0 0 t\n\
    LeaveEvent 306 51 0 0 0 t\n\
    EnterEvent 298 52 0 0 0 t\n\
    MouseMoveEvent 298 52 0 0 0 t\n\
    MouseMoveEvent 295 50 0 0 0 t\n\
    MouseMoveEvent 290 49 0 0 0 t\n\
    MouseMoveEvent 285 48 0 0 0 t\n\
    MouseMoveEvent 277 45 0 0 0 t\n\
    MouseMoveEvent 273 45 0 0 0 t\n\
    MouseMoveEvent 270 43 0 0 0 t\n\
    MouseMoveEvent 265 43 0 0 0 t\n\
    MouseMoveEvent 261 41 0 0 0 t\n\
    MouseMoveEvent 259 41 0 0 0 t\n\
    MouseMoveEvent 256 41 0 0 0 t\n\
    MouseMoveEvent 254 41 0 0 0 t\n\
    MouseMoveEvent 251 40 0 0 0 t\n\
    MouseMoveEvent 249 39 0 0 0 t\n\
    MouseMoveEvent 247 39 0 0 0 t\n\
    MouseMoveEvent 245 39 0 0 0 t\n\
    MouseMoveEvent 240 39 0 0 0 t\n\
    MouseMoveEvent 239 39 0 0 0 t\n\
    MouseMoveEvent 238 38 0 0 0 t\n\
    MouseMoveEvent 237 38 0 0 0 t\n\
    MouseMoveEvent 236 37 0 0 0 t\n\
    MouseMoveEvent 235 37 0 0 0 t\n\
    MouseMoveEvent 233 37 0 0 0 t\n\
    MouseMoveEvent 233 37 0 0 0 t\n\
    LeftButtonPressEvent 233 37 0 0 0 t\n\
    StartInteractionEvent 233 37 0 0 0 t\n\
    MouseMoveEvent 233 37 0 0 0 t\n\
    RenderEvent 233 37 0 0 0 t\n\
    InteractionEvent 233 37 0 0 0 t\n\
    MouseMoveEvent 234 37 0 0 0 t\n\
    RenderEvent 234 37 0 0 0 t\n\
    InteractionEvent 234 37 0 0 0 t\n\
    MouseMoveEvent 236 36 0 0 0 t\n\
    RenderEvent 236 36 0 0 0 t\n\
    InteractionEvent 236 36 0 0 0 t\n\
    MouseMoveEvent 238 36 0 0 0 t\n\
    RenderEvent 238 36 0 0 0 t\n\
    InteractionEvent 238 36 0 0 0 t\n\
    MouseMoveEvent 244 33 0 0 0 t\n\
    RenderEvent 244 33 0 0 0 t\n\
    InteractionEvent 244 33 0 0 0 t\n\
    MouseMoveEvent 250 32 0 0 0 t\n\
    RenderEvent 250 32 0 0 0 t\n\
    InteractionEvent 250 32 0 0 0 t\n\
    MouseMoveEvent 261 30 0 0 0 t\n\
    RenderEvent 261 30 0 0 0 t\n\
    InteractionEvent 261 30 0 0 0 t\n\
    MouseMoveEvent 270 27 0 0 0 t\n\
    RenderEvent 270 27 0 0 0 t\n\
    InteractionEvent 270 27 0 0 0 t\n\
    MouseMoveEvent 274 26 0 0 0 t\n\
    RenderEvent 274 26 0 0 0 t\n\
    InteractionEvent 274 26 0 0 0 t\n\
    MouseMoveEvent 277 25 0 0 0 t\n\
    RenderEvent 277 25 0 0 0 t\n\
    InteractionEvent 277 25 0 0 0 t\n\
    MouseMoveEvent 280 24 0 0 0 t\n\
    RenderEvent 280 24 0 0 0 t\n\
    InteractionEvent 280 24 0 0 0 t\n\
    MouseMoveEvent 281 24 0 0 0 t\n\
    RenderEvent 281 24 0 0 0 t\n\
    InteractionEvent 281 24 0 0 0 t\n\
    MouseMoveEvent 282 24 0 0 0 t\n\
    RenderEvent 282 24 0 0 0 t\n\
    InteractionEvent 282 24 0 0 0 t\n\
    MouseMoveEvent 284 23 0 0 0 t\n\
    RenderEvent 284 23 0 0 0 t\n\
    InteractionEvent 284 23 0 0 0 t\n\
    MouseMoveEvent 286 22 0 0 0 t\n\
    RenderEvent 286 22 0 0 0 t\n\
    InteractionEvent 286 22 0 0 0 t\n\
    MouseMoveEvent 287 22 0 0 0 t\n\
    RenderEvent 287 22 0 0 0 t\n\
    InteractionEvent 287 22 0 0 0 t\n\
    MouseMoveEvent 288 22 0 0 0 t\n\
    RenderEvent 288 22 0 0 0 t\n\
    InteractionEvent 288 22 0 0 0 t\n\
    LeftButtonReleaseEvent 288 22 0 0 0 t\n\
    EndInteractionEvent 288 22 0 0 0 t\n\
    RenderEvent 288 22 0 0 0 t\n\
    MouseMoveEvent 287 22 0 0 0 t\n\
    MouseMoveEvent 286 23 0 0 0 t\n\
    MouseMoveEvent 285 23 0 0 0 t\n\
    MouseMoveEvent 283 25 0 0 0 t\n\
    MouseMoveEvent 282 25 0 0 0 t\n\
    MouseMoveEvent 279 29 0 0 0 t\n\
    MouseMoveEvent 276 31 0 0 0 t\n\
    MouseMoveEvent 273 35 0 0 0 t\n\
    MouseMoveEvent 270 38 0 0 0 t\n\
    MouseMoveEvent 266 44 0 0 0 t\n\
    MouseMoveEvent 262 51 0 0 0 t\n\
    MouseMoveEvent 259 57 0 0 0 t\n\
    MouseMoveEvent 256 65 0 0 0 t\n\
    MouseMoveEvent 251 73 0 0 0 t\n\
    MouseMoveEvent 248 79 0 0 0 t\n\
    MouseMoveEvent 244 84 0 0 0 t\n\
    MouseMoveEvent 241 90 0 0 0 t\n\
    MouseMoveEvent 240 94 0 0 0 t\n\
    MouseMoveEvent 237 99 0 0 0 t\n\
    MouseMoveEvent 236 101 0 0 0 t\n\
    MouseMoveEvent 235 103 0 0 0 t\n\
    MouseMoveEvent 234 105 0 0 0 t\n\
    MouseMoveEvent 233 107 0 0 0 t\n\
    MouseMoveEvent 232 107 0 0 0 t\n\
    MouseMoveEvent 232 109 0 0 0 t\n\
    MouseMoveEvent 232 110 0 0 0 t\n\
    MouseMoveEvent 231 111 0 0 0 t\n\
    MouseMoveEvent 231 112 0 0 0 t\n\
    MouseMoveEvent 231 113 0 0 0 t\n\
    MouseMoveEvent 231 115 0 0 0 t\n\
    MouseMoveEvent 231 116 0 0 0 t\n\
    MouseMoveEvent 231 117 0 0 0 t\n\
    MouseMoveEvent 231 119 0 0 0 t\n\
    MouseMoveEvent 231 121 0 0 0 t\n\
    MouseMoveEvent 231 123 0 0 0 t\n\
    MouseMoveEvent 232 125 0 0 0 t\n\
    MouseMoveEvent 233 127 0 0 0 t\n\
    MouseMoveEvent 233 128 0 0 0 t\n\
    MouseMoveEvent 233 130 0 0 0 t\n\
    MouseMoveEvent 234 131 0 0 0 t\n\
    MouseMoveEvent 234 132 0 0 0 t\n\
    MouseMoveEvent 234 134 0 0 0 t\n\
    MouseMoveEvent 235 135 0 0 0 t\n\
    MouseMoveEvent 235 136 0 0 0 t\n\
    MouseMoveEvent 235 137 0 0 0 t\n\
    MouseMoveEvent 235 138 0 0 0 t\n\
    MouseMoveEvent 236 139 0 0 0 t\n\
    MouseMoveEvent 236 140 0 0 0 t\n\
    MouseMoveEvent 235 140 0 0 0 t\n\
    MouseMoveEvent 235 139 0 0 0 t\n\
    MouseMoveEvent 234 139 0 0 0 t\n\
    MouseMoveEvent 233 139 0 0 0 t\n\
    MouseMoveEvent 232 138 0 0 0 t\n\
    MouseMoveEvent 231 137 0 0 0 t\n\
    MouseMoveEvent 230 137 0 0 0 t\n\
    MouseMoveEvent 229 136 0 0 0 t\n\
    LeftButtonPressEvent 229 136 0 0 0 t\n\
    RenderEvent 229 136 0 0 0 t\n\
    MouseMoveEvent 229 135 0 0 0 t\n\
    RenderEvent 229 135 0 0 0 t\n\
    MouseMoveEvent 230 134 0 0 0 t\n\
    RenderEvent 230 134 0 0 0 t\n\
    MouseMoveEvent 231 134 0 0 0 t\n\
    RenderEvent 231 134 0 0 0 t\n\
    MouseMoveEvent 233 133 0 0 0 t\n\
    RenderEvent 233 133 0 0 0 t\n\
    MouseMoveEvent 235 132 0 0 0 t\n\
    RenderEvent 235 132 0 0 0 t\n\
    MouseMoveEvent 242 130 0 0 0 t\n\
    RenderEvent 242 130 0 0 0 t\n\
    MouseMoveEvent 250 127 0 0 0 t\n\
    RenderEvent 250 127 0 0 0 t\n\
    MouseMoveEvent 254 125 0 0 0 t\n\
    RenderEvent 254 125 0 0 0 t\n\
    MouseMoveEvent 256 125 0 0 0 t\n\
    RenderEvent 256 125 0 0 0 t\n\
    MouseMoveEvent 257 125 0 0 0 t\n\
    RenderEvent 257 125 0 0 0 t\n\
    MouseMoveEvent 257 124 0 0 0 t\n\
    RenderEvent 257 124 0 0 0 t\n\
    MouseMoveEvent 259 124 0 0 0 t\n\
    RenderEvent 259 124 0 0 0 t\n\
    MouseMoveEvent 261 124 0 0 0 t\n\
    RenderEvent 261 124 0 0 0 t\n\
    MouseMoveEvent 262 123 0 0 0 t\n\
    RenderEvent 262 123 0 0 0 t\n\
    MouseMoveEvent 263 123 0 0 0 t\n\
    RenderEvent 263 123 0 0 0 t\n\
    MouseMoveEvent 264 122 0 0 0 t\n\
    RenderEvent 264 122 0 0 0 t\n\
    MouseMoveEvent 265 121 0 0 0 t\n\
    RenderEvent 265 121 0 0 0 t\n\
    MouseMoveEvent 266 121 0 0 0 t\n\
    RenderEvent 266 121 0 0 0 t\n\
    MouseMoveEvent 267 121 0 0 0 t\n\
    RenderEvent 267 121 0 0 0 t\n\
    MouseMoveEvent 269 121 0 0 0 t\n\
    RenderEvent 269 121 0 0 0 t\n\
    MouseMoveEvent 270 121 0 0 0 t\n\
    RenderEvent 270 121 0 0 0 t\n\
    MouseMoveEvent 271 120 0 0 0 t\n\
    RenderEvent 271 120 0 0 0 t\n\
    MouseMoveEvent 273 120 0 0 0 t\n\
    RenderEvent 273 120 0 0 0 t\n\
    MouseMoveEvent 275 119 0 0 0 t\n\
    RenderEvent 275 119 0 0 0 t\n\
    MouseMoveEvent 276 118 0 0 0 t\n\
    RenderEvent 276 118 0 0 0 t\n\
    MouseMoveEvent 277 118 0 0 0 t\n\
    RenderEvent 277 118 0 0 0 t\n\
    MouseMoveEvent 278 118 0 0 0 t\n\
    RenderEvent 278 118 0 0 0 t\n\
    MouseMoveEvent 278 118 0 0 0 t\n\
    RenderEvent 278 118 0 0 0 t\n\
    MouseMoveEvent 280 118 0 0 0 t\n\
    RenderEvent 280 118 0 0 0 t\n\
    MouseMoveEvent 280 117 0 0 0 t\n\
    RenderEvent 280 117 0 0 0 t\n\
    MouseMoveEvent 281 117 0 0 0 t\n\
    RenderEvent 281 117 0 0 0 t\n\
    MouseMoveEvent 282 117 0 0 0 t\n\
    RenderEvent 282 117 0 0 0 t\n\
    MouseMoveEvent 283 116 0 0 0 t\n\
    RenderEvent 283 116 0 0 0 t\n\
    MouseMoveEvent 285 116 0 0 0 t\n\
    RenderEvent 285 116 0 0 0 t\n\
    MouseMoveEvent 286 115 0 0 0 t\n\
    RenderEvent 286 115 0 0 0 t\n\
    MouseMoveEvent 287 115 0 0 0 t\n\
    RenderEvent 287 115 0 0 0 t\n\
    MouseMoveEvent 288 115 0 0 0 t\n\
    RenderEvent 288 115 0 0 0 t\n\
    MouseMoveEvent 288 115 0 0 0 t\n\
    RenderEvent 288 115 0 0 0 t\n\
    MouseMoveEvent 290 114 0 0 0 t\n\
    RenderEvent 290 114 0 0 0 t\n\
    MouseMoveEvent 291 114 0 0 0 t\n\
    RenderEvent 291 114 0 0 0 t\n\
    MouseMoveEvent 292 114 0 0 0 t\n\
    RenderEvent 292 114 0 0 0 t\n\
    MouseMoveEvent 292 113 0 0 0 t\n\
    RenderEvent 292 113 0 0 0 t\n\
    MouseMoveEvent 293 112 0 0 0 t\n\
    RenderEvent 293 112 0 0 0 t\n\
    LeftButtonReleaseEvent 293 112 0 0 0 t\n\
    RenderEvent 293 112 0 0 0 t\n\
    MouseMoveEvent 293 113 0 0 0 t\n\
    MouseMoveEvent 291 113 0 0 0 t\n\
    MouseMoveEvent 291 115 0 0 0 t\n\
    MouseMoveEvent 289 115 0 0 0 t\n\
    MouseMoveEvent 288 117 0 0 0 t\n\
    MouseMoveEvent 285 117 0 0 0 t\n\
    MouseMoveEvent 281 119 0 0 0 t\n\
    MouseMoveEvent 276 123 0 0 0 t\n\
    MouseMoveEvent 272 128 0 0 0 t\n\
    MouseMoveEvent 266 132 0 0 0 t\n\
    MouseMoveEvent 258 138 0 0 0 t\n\
    MouseMoveEvent 250 145 0 0 0 t\n\
    MouseMoveEvent 241 152 0 0 0 t\n\
    MouseMoveEvent 235 158 0 0 0 t\n\
    MouseMoveEvent 230 164 0 0 0 t\n\
    MouseMoveEvent 226 170 0 0 0 t\n\
    MouseMoveEvent 221 176 0 0 0 t\n\
    MouseMoveEvent 219 180 0 0 0 t\n\
    MouseMoveEvent 217 185 0 0 0 t\n\
    MouseMoveEvent 215 188 0 0 0 t\n\
    MouseMoveEvent 212 193 0 0 0 t\n\
    MouseMoveEvent 211 195 0 0 0 t\n\
    MouseMoveEvent 208 198 0 0 0 t\n\
    MouseMoveEvent 208 204 0 0 0 t\n\
    MouseMoveEvent 205 206 0 0 0 t\n\
    MouseMoveEvent 203 209 0 0 0 t\n\
    MouseMoveEvent 202 213 0 0 0 t\n\
    MouseMoveEvent 198 218 0 0 0 t\n\
    MouseMoveEvent 197 224 0 0 0 t\n\
    MouseMoveEvent 192 231 0 0 0 t\n\
    MouseMoveEvent 189 239 0 0 0 t\n\
    MouseMoveEvent 186 245 0 0 0 t\n\
    MouseMoveEvent 183 250 0 0 0 t\n\
    MouseMoveEvent 181 256 0 0 0 t\n\
    MouseMoveEvent 178 261 0 0 0 t\n\
    MouseMoveEvent 177 263 0 0 0 t\n\
    MouseMoveEvent 176 267 0 0 0 t\n\
    MouseMoveEvent 175 270 0 0 0 t\n\
    MouseMoveEvent 173 275 0 0 0 t\n\
    MouseMoveEvent 172 280 0 0 0 t\n\
    MouseMoveEvent 171 285 0 0 0 t\n\
    MouseMoveEvent 169 291 0 0 0 t\n\
    MouseMoveEvent 169 296 0 0 0 t\n\
    LeaveEvent 168 300 0 0 0 t\n\
    EnterEvent 168 298 0 0 0 t\n\
    MouseMoveEvent 168 298 0 0 0 t\n\
    MouseMoveEvent 168 296 0 0 0 t\n\
    MouseMoveEvent 168 293 0 0 0 t\n\
    MouseMoveEvent 168 291 0 0 0 t\n\
    MouseMoveEvent 168 289 0 0 0 t\n\
    MouseMoveEvent 168 287 0 0 0 t\n\
    MouseMoveEvent 168 283 0 0 0 t\n\
    MouseMoveEvent 168 282 0 0 0 t\n\
    MouseMoveEvent 169 279 0 0 0 t\n\
    MouseMoveEvent 169 275 0 0 0 t\n\
    MouseMoveEvent 169 273 0 0 0 t\n\
    MouseMoveEvent 169 271 0 0 0 t\n\
    MouseMoveEvent 169 269 0 0 0 t\n\
    MouseMoveEvent 169 267 0 0 0 t\n\
    MouseMoveEvent 170 266 0 0 0 t\n\
    MouseMoveEvent 170 265 0 0 0 t\n\
    MouseMoveEvent 170 264 0 0 0 t\n\
    MouseMoveEvent 170 263 0 0 0 t\n\
    MouseMoveEvent 171 263 0 0 0 t\n\
    MouseMoveEvent 171 262 0 0 0 t\n\
    MouseMoveEvent 172 261 0 0 0 t\n\
    MouseMoveEvent 173 260 0 0 0 t\n\
    MouseMoveEvent 173 259 0 0 0 t\n\
    MouseMoveEvent 174 258 0 0 0 t\n\
    MouseMoveEvent 175 257 0 0 0 t\n\
    MouseMoveEvent 175 256 0 0 0 t\n\
    MouseMoveEvent 175 256 0 0 0 t\n\
    MouseMoveEvent 176 256 0 0 0 t\n\
    KeyPressEvent 176 256 0 114 1 r\n\
    CharEvent 176 256 0 114 1 r\n\
    RenderEvent 176 256 0 114 1 r\n\
    KeyReleaseEvent 176 256 0 114 1 r\n\
    MouseMoveEvent 176 255 0 0 0 r\n\
    MouseMoveEvent 176 254 0 0 0 r\n\
    MouseMoveEvent 175 253 0 0 0 r\n\
    MouseMoveEvent 175 251 0 0 0 r\n\
    MouseMoveEvent 174 249 0 0 0 r\n\
    MouseMoveEvent 174 246 0 0 0 r\n\
    MouseMoveEvent 172 241 0 0 0 r\n\
    MouseMoveEvent 171 239 0 0 0 r\n\
    MouseMoveEvent 171 234 0 0 0 r\n\
    MouseMoveEvent 170 229 0 0 0 r\n\
    MouseMoveEvent 169 220 0 0 0 r\n\
    MouseMoveEvent 167 216 0 0 0 r\n\
    MouseMoveEvent 166 211 0 0 0 r\n\
    MouseMoveEvent 165 207 0 0 0 r\n\
    MouseMoveEvent 163 202 0 0 0 r\n\
    MouseMoveEvent 161 198 0 0 0 r\n\
    MouseMoveEvent 161 196 0 0 0 r\n\
    MouseMoveEvent 159 193 0 0 0 r\n\
    MouseMoveEvent 159 192 0 0 0 r\n\
    MouseMoveEvent 159 189 0 0 0 r\n\
    MouseMoveEvent 158 187 0 0 0 r\n\
    MouseMoveEvent 157 186 0 0 0 r\n\
    MouseMoveEvent 157 183 0 0 0 r\n\
    MouseMoveEvent 155 182 0 0 0 r\n\
    MouseMoveEvent 155 180 0 0 0 r\n\
    MouseMoveEvent 154 178 0 0 0 r\n\
    MouseMoveEvent 153 176 0 0 0 r\n\
    MouseMoveEvent 152 174 0 0 0 r\n\
    MouseMoveEvent 152 172 0 0 0 r\n\
    MouseMoveEvent 151 170 0 0 0 r\n\
    MouseMoveEvent 151 172 0 0 0 r\n\
    MouseMoveEvent 151 173 0 0 0 r\n\
    MouseMoveEvent 151 174 0 0 0 r\n\
    MouseMoveEvent 151 179 0 0 0 r\n\
    MouseMoveEvent 151 180 0 0 0 r\n\
    MouseMoveEvent 152 182 0 0 0 r\n\
    MouseMoveEvent 152 184 0 0 0 r\n\
    MouseMoveEvent 153 186 0 0 0 r\n\
    MouseMoveEvent 153 187 0 0 0 r\n\
    MouseMoveEvent 153 188 0 0 0 r\n\
    MouseMoveEvent 154 189 0 0 0 r\n\
    MouseMoveEvent 154 190 0 0 0 r\n\
    MouseMoveEvent 155 191 0 0 0 r\n\
    MouseMoveEvent 155 192 0 0 0 r\n\
    MouseMoveEvent 155 193 0 0 0 r\n\
    MouseMoveEvent 156 195 0 0 0 r\n\
    MouseMoveEvent 156 197 0 0 0 r\n\
    MouseMoveEvent 157 199 0 0 0 r\n\
    MouseMoveEvent 157 201 0 0 0 r\n\
    MouseMoveEvent 157 203 0 0 0 r\n\
    MouseMoveEvent 157 205 0 0 0 r\n\
    MouseMoveEvent 158 207 0 0 0 r\n\
    MouseMoveEvent 158 209 0 0 0 r\n\
    MouseMoveEvent 158 210 0 0 0 r\n\
    MouseMoveEvent 159 211 0 0 0 r\n\
    MouseMoveEvent 159 212 0 0 0 r\n\
    MouseMoveEvent 159 212 0 0 0 r\n\
    MouseMoveEvent 159 213 0 0 0 r\n\
    MouseMoveEvent 158 213 0 0 0 r\n\
    LeftButtonPressEvent 158 213 0 0 0 r\n\
    RenderEvent 158 213 0 0 0 r\n\
    MouseMoveEvent 158 214 0 0 0 r\n\
    RenderEvent 158 214 0 0 0 r\n\
    MouseMoveEvent 158 214 0 0 0 r\n\
    RenderEvent 158 214 0 0 0 r\n\
    MouseMoveEvent 158 215 0 0 0 r\n\
    RenderEvent 158 215 0 0 0 r\n\
    MouseMoveEvent 158 218 0 0 0 r\n\
    RenderEvent 158 218 0 0 0 r\n\
    MouseMoveEvent 158 220 0 0 0 r\n\
    RenderEvent 158 220 0 0 0 r\n\
    MouseMoveEvent 158 222 0 0 0 r\n\
    RenderEvent 158 222 0 0 0 r\n\
    MouseMoveEvent 157 223 0 0 0 r\n\
    RenderEvent 157 223 0 0 0 r\n\
    MouseMoveEvent 157 224 0 0 0 r\n\
    RenderEvent 157 224 0 0 0 r\n\
    MouseMoveEvent 156 225 0 0 0 r\n\
    RenderEvent 156 225 0 0 0 r\n\
    MouseMoveEvent 156 226 0 0 0 r\n\
    RenderEvent 156 226 0 0 0 r\n\
    MouseMoveEvent 156 227 0 0 0 r\n\
    RenderEvent 156 227 0 0 0 r\n\
    MouseMoveEvent 156 229 0 0 0 r\n\
    RenderEvent 156 229 0 0 0 r\n\
    MouseMoveEvent 156 231 0 0 0 r\n\
    RenderEvent 156 231 0 0 0 r\n\
    MouseMoveEvent 156 233 0 0 0 r\n\
    RenderEvent 156 233 0 0 0 r\n\
    MouseMoveEvent 156 235 0 0 0 r\n\
    RenderEvent 156 235 0 0 0 r\n\
    MouseMoveEvent 156 236 0 0 0 r\n\
    RenderEvent 156 236 0 0 0 r\n\
    MouseMoveEvent 157 236 0 0 0 r\n\
    RenderEvent 157 236 0 0 0 r\n\
    MouseMoveEvent 160 237 0 0 0 r\n\
    RenderEvent 160 237 0 0 0 r\n\
    MouseMoveEvent 164 237 0 0 0 r\n\
    RenderEvent 164 237 0 0 0 r\n\
    MouseMoveEvent 168 238 0 0 0 r\n\
    RenderEvent 168 238 0 0 0 r\n\
    MouseMoveEvent 171 238 0 0 0 r\n\
    RenderEvent 171 238 0 0 0 r\n\
    MouseMoveEvent 172 238 0 0 0 r\n\
    RenderEvent 172 238 0 0 0 r\n\
    MouseMoveEvent 175 238 0 0 0 r\n\
    RenderEvent 175 238 0 0 0 r\n\
    MouseMoveEvent 177 238 0 0 0 r\n\
    RenderEvent 177 238 0 0 0 r\n\
    MouseMoveEvent 179 238 0 0 0 r\n\
    RenderEvent 179 238 0 0 0 r\n\
    MouseMoveEvent 180 237 0 0 0 r\n\
    RenderEvent 180 237 0 0 0 r\n\
    MouseMoveEvent 181 237 0 0 0 r\n\
    RenderEvent 181 237 0 0 0 r\n\
    MouseMoveEvent 183 237 0 0 0 r\n\
    RenderEvent 183 237 0 0 0 r\n\
    MouseMoveEvent 184 237 0 0 0 r\n\
    RenderEvent 184 237 0 0 0 r\n\
    MouseMoveEvent 184 237 0 0 0 r\n\
    RenderEvent 184 237 0 0 0 r\n\
    MouseMoveEvent 186 237 0 0 0 r\n\
    RenderEvent 186 237 0 0 0 r\n\
    MouseMoveEvent 186 237 0 0 0 r\n\
    RenderEvent 186 237 0 0 0 r\n\
    MouseMoveEvent 187 237 0 0 0 r\n\
    RenderEvent 187 237 0 0 0 r\n\
    MouseMoveEvent 188 237 0 0 0 r\n\
    RenderEvent 188 237 0 0 0 r\n\
    MouseMoveEvent 190 237 0 0 0 r\n\
    RenderEvent 190 237 0 0 0 r\n\
    MouseMoveEvent 192 236 0 0 0 r\n\
    RenderEvent 192 236 0 0 0 r\n\
    MouseMoveEvent 193 236 0 0 0 r\n\
    RenderEvent 193 236 0 0 0 r\n\
    MouseMoveEvent 194 236 0 0 0 r\n\
    RenderEvent 194 236 0 0 0 r\n\
    MouseMoveEvent 195 236 0 0 0 r\n\
    RenderEvent 195 236 0 0 0 r\n\
    MouseMoveEvent 196 235 0 0 0 r\n\
    RenderEvent 196 235 0 0 0 r\n\
    MouseMoveEvent 197 234 0 0 0 r\n\
    RenderEvent 197 234 0 0 0 r\n\
    MouseMoveEvent 198 233 0 0 0 r\n\
    RenderEvent 198 233 0 0 0 r\n\
    MouseMoveEvent 200 231 0 0 0 r\n\
    RenderEvent 200 231 0 0 0 r\n\
    MouseMoveEvent 201 230 0 0 0 r\n\
    RenderEvent 201 230 0 0 0 r\n\
    MouseMoveEvent 203 227 0 0 0 r\n\
    RenderEvent 203 227 0 0 0 r\n\
    MouseMoveEvent 203 226 0 0 0 r\n\
    RenderEvent 203 226 0 0 0 r\n\
    MouseMoveEvent 204 225 0 0 0 r\n\
    RenderEvent 204 225 0 0 0 r\n\
    MouseMoveEvent 205 224 0 0 0 r\n\
    RenderEvent 205 224 0 0 0 r\n\
    MouseMoveEvent 205 223 0 0 0 r\n\
    RenderEvent 205 223 0 0 0 r\n\
    MouseMoveEvent 205 221 0 0 0 r\n\
    RenderEvent 205 221 0 0 0 r\n\
    MouseMoveEvent 205 219 0 0 0 r\n\
    RenderEvent 205 219 0 0 0 r\n\
    MouseMoveEvent 205 217 0 0 0 r\n\
    RenderEvent 205 217 0 0 0 r\n\
    MouseMoveEvent 205 215 0 0 0 r\n\
    RenderEvent 205 215 0 0 0 r\n\
    MouseMoveEvent 205 214 0 0 0 r\n\
    RenderEvent 205 214 0 0 0 r\n\
    MouseMoveEvent 205 212 0 0 0 r\n\
    RenderEvent 205 212 0 0 0 r\n\
    MouseMoveEvent 205 210 0 0 0 r\n\
    RenderEvent 205 210 0 0 0 r\n\
    MouseMoveEvent 204 207 0 0 0 r\n\
    RenderEvent 204 207 0 0 0 r\n\
    MouseMoveEvent 204 206 0 0 0 r\n\
    RenderEvent 204 206 0 0 0 r\n\
    MouseMoveEvent 203 205 0 0 0 r\n\
    RenderEvent 203 205 0 0 0 r\n\
    MouseMoveEvent 203 203 0 0 0 r\n\
    RenderEvent 203 203 0 0 0 r\n\
    MouseMoveEvent 202 202 0 0 0 r\n\
    RenderEvent 202 202 0 0 0 r\n\
    MouseMoveEvent 202 199 0 0 0 r\n\
    RenderEvent 202 199 0 0 0 r\n\
    MouseMoveEvent 201 198 0 0 0 r\n\
    RenderEvent 201 198 0 0 0 r\n\
    MouseMoveEvent 201 197 0 0 0 r\n\
    RenderEvent 201 197 0 0 0 r\n\
    MouseMoveEvent 200 195 0 0 0 r\n\
    RenderEvent 200 195 0 0 0 r\n\
    MouseMoveEvent 200 193 0 0 0 r\n\
    RenderEvent 200 193 0 0 0 r\n\
    MouseMoveEvent 200 191 0 0 0 r\n\
    RenderEvent 200 191 0 0 0 r\n\
    MouseMoveEvent 199 189 0 0 0 r\n\
    RenderEvent 199 189 0 0 0 r\n\
    MouseMoveEvent 198 188 0 0 0 r\n\
    RenderEvent 198 188 0 0 0 r\n\
    MouseMoveEvent 198 187 0 0 0 r\n\
    RenderEvent 198 187 0 0 0 r\n\
    LeftButtonReleaseEvent 198 187 0 0 0 r\n\
    RenderEvent 198 187 0 0 0 r\n\
    MouseMoveEvent 197 187 0 0 0 r\n\
    MouseMoveEvent 197 188 0 0 0 r\n\
    MouseMoveEvent 196 188 0 0 0 r\n\
    MouseMoveEvent 194 189 0 0 0 r\n\
    MouseMoveEvent 192 190 0 0 0 r\n\
    MouseMoveEvent 187 191 0 0 0 r\n\
    MouseMoveEvent 183 191 0 0 0 r\n\
    MouseMoveEvent 180 194 0 0 0 r\n\
    MouseMoveEvent 176 195 0 0 0 r\n\
    MouseMoveEvent 171 196 0 0 0 r\n\
    MouseMoveEvent 166 197 0 0 0 r\n\
    MouseMoveEvent 164 198 0 0 0 r\n\
    MouseMoveEvent 162 199 0 0 0 r\n\
    MouseMoveEvent 160 200 0 0 0 r\n\
    MouseMoveEvent 160 201 0 0 0 r\n\
    MouseMoveEvent 158 201 0 0 0 r\n\
    MouseMoveEvent 156 201 0 0 0 r\n\
    MouseMoveEvent 155 202 0 0 0 r\n\
    MouseMoveEvent 154 202 0 0 0 r\n\
    MouseMoveEvent 153 202 0 0 0 r\n\
    MouseMoveEvent 152 202 0 0 0 r\n\
    MouseMoveEvent 151 203 0 0 0 r\n\
    MouseMoveEvent 150 203 0 0 0 r\n\
    MouseMoveEvent 150 203 0 0 0 r\n\
    MouseMoveEvent 148 204 0 0 0 r\n\
    MouseMoveEvent 147 204 0 0 0 r\n\
    MouseMoveEvent 146 205 0 0 0 r\n\
    MouseMoveEvent 145 205 0 0 0 r\n\
    MouseMoveEvent 144 207 0 0 0 r\n\
    LeftButtonPressEvent 144 207 0 0 0 r\n\
    RenderEvent 144 207 0 0 0 r\n\
    MouseMoveEvent 144 208 0 0 0 r\n\
    RenderEvent 144 208 0 0 0 r\n\
    MouseMoveEvent 144 209 0 0 0 r\n\
    RenderEvent 144 209 0 0 0 r\n\
    MouseMoveEvent 144 210 0 0 0 r\n\
    RenderEvent 144 210 0 0 0 r\n\
    MouseMoveEvent 144 211 0 0 0 r\n\
    RenderEvent 144 211 0 0 0 r\n\
    MouseMoveEvent 144 212 0 0 0 r\n\
    RenderEvent 144 212 0 0 0 r\n\
    MouseMoveEvent 144 213 0 0 0 r\n\
    RenderEvent 144 213 0 0 0 r\n\
    MouseMoveEvent 144 214 0 0 0 r\n\
    RenderEvent 144 214 0 0 0 r\n\
    MouseMoveEvent 145 216 0 0 0 r\n\
    RenderEvent 145 216 0 0 0 r\n\
    MouseMoveEvent 145 217 0 0 0 r\n\
    RenderEvent 145 217 0 0 0 r\n\
    MouseMoveEvent 145 219 0 0 0 r\n\
    RenderEvent 145 219 0 0 0 r\n\
    MouseMoveEvent 145 220 0 0 0 r\n\
    RenderEvent 145 220 0 0 0 r\n\
    MouseMoveEvent 145 221 0 0 0 r\n\
    RenderEvent 145 221 0 0 0 r\n\
    MouseMoveEvent 145 223 0 0 0 r\n\
    RenderEvent 145 223 0 0 0 r\n\
    MouseMoveEvent 145 224 0 0 0 r\n\
    RenderEvent 145 224 0 0 0 r\n\
    MouseMoveEvent 145 225 0 0 0 r\n\
    RenderEvent 145 225 0 0 0 r\n\
    MouseMoveEvent 145 225 0 0 0 r\n\
    RenderEvent 145 225 0 0 0 r\n\
    MouseMoveEvent 145 226 0 0 0 r\n\
    RenderEvent 145 226 0 0 0 r\n\
    MouseMoveEvent 145 227 0 0 0 r\n\
    RenderEvent 145 227 0 0 0 r\n\
    MouseMoveEvent 145 228 0 0 0 r\n\
    RenderEvent 145 228 0 0 0 r\n\
    MouseMoveEvent 145 229 0 0 0 r\n\
    RenderEvent 145 229 0 0 0 r\n\
    MouseMoveEvent 145 230 0 0 0 r\n\
    RenderEvent 145 230 0 0 0 r\n\
    MouseMoveEvent 145 231 0 0 0 r\n\
    RenderEvent 145 231 0 0 0 r\n\
    MouseMoveEvent 145 232 0 0 0 r\n\
    RenderEvent 145 232 0 0 0 r\n\
    MouseMoveEvent 145 233 0 0 0 r\n\
    RenderEvent 145 233 0 0 0 r\n\
    MouseMoveEvent 145 235 0 0 0 r\n\
    RenderEvent 145 235 0 0 0 r\n\
    MouseMoveEvent 145 236 0 0 0 r\n\
    RenderEvent 145 236 0 0 0 r\n\
    MouseMoveEvent 144 237 0 0 0 r\n\
    RenderEvent 144 237 0 0 0 r\n\
    MouseMoveEvent 144 237 0 0 0 r\n\
    RenderEvent 144 237 0 0 0 r\n\
    MouseMoveEvent 144 238 0 0 0 r\n\
    RenderEvent 144 238 0 0 0 r\n\
    MouseMoveEvent 144 239 0 0 0 r\n\
    RenderEvent 144 239 0 0 0 r\n\
    MouseMoveEvent 144 239 0 0 0 r\n\
    RenderEvent 144 239 0 0 0 r\n\
    MouseMoveEvent 144 240 0 0 0 r\n\
    RenderEvent 144 240 0 0 0 r\n\
    MouseMoveEvent 144 241 0 0 0 r\n\
    RenderEvent 144 241 0 0 0 r\n\
    MouseMoveEvent 144 242 0 0 0 r\n\
    RenderEvent 144 242 0 0 0 r\n\
    MouseMoveEvent 144 243 0 0 0 r\n\
    RenderEvent 144 243 0 0 0 r\n\
    LeftButtonReleaseEvent 144 243 0 0 0 r\n\
    RenderEvent 144 243 0 0 0 r\n\
    "

# Create the RenderWindow, Renderer and both Actors
#
ren = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren)

iRen = vtkRenderWindowInteractor()
iRen.SetRenderWindow(renWin);

# Define callback for the widget
def SelectPolygons(widget, event_string):
    '''
    The callback takes two parameters.
    Parameters:
      widget - the object that generates the event.
      event_string - the event name (which is a string).
    '''
    tsWidget

# Create a representation for the widget
bbox = [-1,1,-1,1,-1,1]
rep = vtkTensorRepresentation()
rep.GetEllipsoidProperty().SetColor(0,0,0)
rep.GetEllipsoidProperty().SetRepresentationToWireframe()
rep.GetOutlineProperty().SetColor(0,0,0)
rep.SetPlaceFactor(1)
rep.PlaceWidget(bbox)

# The widget proper
tsWidget = vtkTensorWidget()
tsWidget.SetInteractor(iRen)
tsWidget.SetRepresentation(rep)
tsWidget.AddObserver("EndInteractionEvent", SelectPolygons)
tsWidget.On()

# Handle playback of events
recorder = vtkInteractorEventRecorder()
recorder.SetInteractor(iRen)
#recorder.SetFileName("record.log")
#recorder.On()
#recorder.Record()
recorder.ReadFromInputStringOn()
recorder.SetInputString(Recording)

# Add the actors to the renderer, set the background and size
#
ren.SetBackground(1,1,1)
renWin.SetSize(300, 300)

# render and interact with data
ren.ResetCamera()
renWin.Render()

# Playack events
recorder.Play()

iRen.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkIdList,
    vtkMath,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    vtkPointLocator,
    vtkPolyData,
    vtkStaticPointLocator,
)
from vtkmodules.vtkCommonSystem import vtkTimerLog

# create a test dataset
#
math = vtkMath()

# Note: the bigger the data the better vtkStaticPointLocator performs
#testSize = "large"
#testSize = "medium"
testSize = "small"

if testSize == "large":
    numPts = 100000000
    numProbes = 1000000
elif testSize == "medium":
    numPts = 2000000
    numProbes = 50000
else:
    numPts = 20000
    numProbes = 5000

# Create an initial set of points and associated dataset
points = vtkPoints()
points.SetDataTypeToDouble()
points.SetNumberOfPoints(numPts)
for i in range(0,numPts):
    points.SetPoint(i,math.Random(-1,1),math.Random(-1,1),math.Random(-1,1))

polydata = vtkPolyData()
polydata.SetPoints(points)
points.ComputeBounds()

# Create points array which are positions to probe data with
# FindClosestPoint(), We also create an array to hold the results of this
# probe operation.
probePoints = vtkPoints()
probePoints.SetDataTypeToDouble()
probePoints.SetNumberOfPoints(numProbes)
math.RandomSeed(314159)
for i in range (0,numProbes):
    probePoints.SetPoint(i,math.Random(-1,1),math.Random(-1,1),math.Random(-1,1))
closest = vtkIdList()
closest.SetNumberOfIds(numProbes)
staticClosest = vtkIdList()
staticClosest.SetNumberOfIds(numProbes)

# Print initial statistics
print("Processing NumPts: {0}".format(numPts))
print("\n")

# Time the creation and building of the incremental point locator
locator = vtkPointLocator()
locator.SetDataSet(polydata)
locator.SetNumberOfPointsPerBucket(5)
locator.AutomaticOn()

timer = vtkTimerLog()
timer.StartTimer()
locator.BuildLocator()
timer.StopTimer()
time = timer.GetElapsedTime()
print("Build Point Locator: {0}".format(time))

# Probe the dataset with FindClosestPoint() and time it
timer.StartTimer()
for i in range (0,numProbes):
    closest.SetId(i, locator.FindClosestPoint(probePoints.GetPoint(i)))
timer.StopTimer()
opTime = timer.GetElapsedTime()
print("    Closest point probing: {0}".format(opTime))
print("    Divisions: {0}".format( locator.GetDivisions() ))

# Poke other methods before deleting locator class
closestN = vtkIdList()
locator.FindClosestNPoints(10, probePoints.GetPoint(0), closestN)

# Time the deletion of the locator. The incremental locator is quite slow due
# to fragmented memory.
timer.StartTimer()
del locator
timer.StopTimer()
time2 = timer.GetElapsedTime()
totalTime = time + opTime + time2
print("    Delete Point Locator: {0}".format(time2))
print("    Point Locator (Total): {0}".format(totalTime))
print("\n")

# StaticPointLocator
# Time the creation of static point locator
staticLocator = vtkStaticPointLocator()
staticLocator.SetDataSet(polydata)
staticLocator.SetNumberOfPointsPerBucket(5)
staticLocator.AutomaticOn()

staticTimer = vtkTimerLog()
staticTimer.StartTimer()
staticLocator.BuildLocator()
staticTimer.StopTimer()
StaticTime = staticTimer.GetElapsedTime()
print("Build Static Point Locator: {0}".format(StaticTime))

# Now probe the dataset with FindClosestPoint()
math.RandomSeed(314159)
staticTimer.StartTimer()
for i in range (0,numProbes):
    staticClosest.SetId(i, staticLocator.FindClosestPoint(probePoints.GetPoint(i)))
staticTimer.StopTimer()
staticOpTime = staticTimer.GetElapsedTime()
print("    Static Closest point probing: {0}".format(staticOpTime))
print("    Divisions: {0}".format( staticLocator.GetDivisions() ))

# Check that closest point operation gives the same answer and the
# incremental point locator. Note that it is possible to realize different
# results because buckets (and hence points) are processed in a different
# order, and if the distance apart is the same then the order decides which
# point is selected (from FindClosestPoint()). For small random datasets this
# is unlikely to happen.
error = 0
x = [0,0,0]
y = [0,0,0]
p = [0,0,0]
math = vtkMath()
for i in range (0,numProbes):
    staticId = staticClosest.GetId(i)
    closestId = closest.GetId(i)
    if closestId != staticId:
        probePoints.GetPoint(i,p)
        points.GetPoint(staticId,x)
        points.GetPoint(closestId,y)
        dx2 = math.Distance2BetweenPoints(x,p)
        dy2 = math.Distance2BetweenPoints(y,p)
        if dx2 != dy2:
            error = 1

# Poke other methods before deleting static locator class
staticClosestN = vtkIdList()
staticLocator.FindClosestNPoints(10, probePoints.GetPoint(0), staticClosestN)
for i in range (0,10):
    staticId = staticClosestN.GetId(i)
    closestId = closestN.GetId(i)
    if staticId != closestId:
        error = 1

# Okay now delete class
staticTimer.StartTimer()
del staticLocator
staticTimer.StopTimer()
StaticTime2 = staticTimer.GetElapsedTime()
totalStaticTime = StaticTime + staticOpTime + StaticTime2

print("    Delete Point Locator: {0}".format(StaticTime2))
print("    Static Point Locator (Total): {0}".format(totalStaticTime))
print("\n")

# Print out the speedups
print("Speed ups:")
if StaticTime > 0.0:
    print("    Build: {0}".format(time/StaticTime))
else:
    print("    Build: (really big)")
if staticOpTime > 0.0:
    print("    Probe: {0}".format(opTime/staticOpTime))
else:
    print("    Probe: (really big)")
if StaticTime2 > 0.0:
    print("    Delete: {0}".format(time2/StaticTime2))
else:
    print("    Delete: (really big)")
if totalStaticTime > 0.0:
    print("    Total: {0}".format(totalTime/totalStaticTime) )
else:
    print("    Total: (really big)")


# Return test results. If the assert is not true, then different results were
# generated by vtkStaticPointLocator and vtkPointLocator.
assert error == 0



from vtkmodules.test import Testing as vtkTesting
import sys

class TestDynamic(vtkTesting.vtkTest):

    def test(self):

        from vtkmodules.vtkSerializationManager import vtkObjectManager
        from vtkmodules.vtkFiltersHybrid import vtkPolyDataSilhouette
        from vtkmodules.vtkFiltersSources import vtkConeSource
        from vtkmodules.vtkRenderingCore import vtkActor, vtkPolyDataMapper, vtkRenderer, vtkRenderWindow, vtkRenderWindowInteractor

        ser_om = vtkObjectManager()
        ser_om.Initialize()

        deser_om = vtkObjectManager()
        deser_om.Initialize()

        renderer = vtkRenderer()
        renderWindow = vtkRenderWindow()
        renderWindow.AddRenderer(renderer)

        renderWindowInteractor = vtkRenderWindowInteractor()
        renderWindowInteractor.SetRenderWindow(renderWindow)

        cone_source = vtkConeSource()
        mapper = vtkPolyDataMapper()
        actor = vtkActor()
        mapper.SetInputConnection(cone_source.GetOutputPort())
        actor.SetMapper(mapper)
        renderer.AddActor(actor)

        sil = vtkPolyDataSilhouette()
        sil.SetInputConnection(cone_source.GetOutputPort())
        sil.SetCamera(renderer.GetActiveCamera())
        silmapper = vtkPolyDataMapper()
        silmapper.SetInputConnection(sil.GetOutputPort())
        silactor = vtkActor()
        silactor.GetProperty().SetColor(1, 0, 0)
        silactor.GetProperty().SetLineWidth(10)
        silactor.SetMapper(silmapper)
        renderer.AddActor(silactor)

        renderer.ResetCamera()
        renderWindow.Render()

        rwi = vtkRenderWindowInteractor()
        rwi.SetRenderWindow(renderWindow)
        renderWindow.Render()

        last_mtimes = dict()
        fname = ""

        def serialize(id_rwi):

            ser_om.UpdateStatesFromObjects()
            active_ids = ser_om.GetAllDependencies(0)

            for vtk_id in active_ids:
                vtk_obj = ser_om.GetObjectAtId(vtk_id)

            status = dict(ids=[], mtimes=[], hashes=[])
            status['ids'] = active_ids
            status['mtimes'] = { object_id: ser_om.GetObjectAtId(object_id).GetMTime() for object_id in active_ids }
            status['hashes'] = { blob_hash: ser_om.GetBlob(blob_hash, True) for blob_hash in ser_om.GetBlobHashes(active_ids) }
            return status

        def deserialize(status: dict):

            if not len(status.get('ids')):
                return

            deser_om.PruneUnusedBlobs()

            for object_id in status.get('ids'):
                new_mtime = status.get('mtimes').get(object_id)
                last_mtime = last_mtimes.get(object_id)
                if last_mtime is not None and new_mtime is not None:
                    if last_mtime < new_mtime:
                        deser_om.UnRegisterState(object_id)
                        deser_om.RegisterState(ser_om.GetState(object_id))
                elif last_mtime is None:
                    deser_om.RegisterState(ser_om.GetState(object_id))
                last_mtimes.update({object_id: new_mtime})
            for hash_text, blob in status.get('hashes').items():
                deser_om.RegisterBlob(hash_text, blob)

            deser_om.UpdateObjectsFromStates()
            active_ids = deser_om.GetAllDependencies(0)

            renderWindow = deser_om.GetObjectAtId(id_rwi).GetRenderWindow()
            renderWindow.SetPosition(400, 1)
            renderWindow.Render()

        id_rwi = ser_om.RegisterObject(rwi)

        maxRes = 100
        for i in range(4, maxRes, 8):
            cone_source.SetResolution(i)
            renderWindow.Render()

            fname = f"output-{i}.vtp"
            deserialize(serialize(id_rwi))

        for i in range(maxRes - 1, 3, -1):
            cone_source.SetResolution(i)
            renderWindow.Render()

            deserialize(serialize(id_rwi))


if __name__ == "__main__":
    vtkTesting.main([(TestDynamic, 'test')])
